-- (C) 2001-2024 Intel Corporation. All rights reserved.
-- Your use of Intel Corporation's design tools, logic functions and other 
-- software and tools, and its AMPP partner logic functions, and any output 
-- files from any of the foregoing (including device programming or simulation 
-- files), and any associated documentation or information are expressly subject 
-- to the terms and conditions of the Intel Program License Subscription 
-- Agreement, Intel FPGA IP License Agreement, or other applicable 
-- license agreement, including, without limitation, that your use is for the 
-- sole purpose of programming logic devices manufactured by Intel and sold by 
-- Intel or its authorized distributors.  Please refer to the applicable 
-- agreement for further details.


library ieee;
use ieee.std_logic_1164.all;

entity sys_max_id is
	port (
		reset_n: in std_logic;
		clk : in std_logic;
		version : in std_logic_vector(15 downto 0);
		inc_num : out std_logic_vector(10 downto 0);
		dec_num : out std_logic_vector(10 downto 0);
		clr_inc_num : in std_logic;
		clr_dec_num : in std_logic;
		control_gui: out std_logic_vector(15 downto 0);
		
		-- interface for AvMM-slave
		slv_en_n : in std_logic;
		slv_address : in std_logic_vector(3 downto 0);
		slv_read_n : in std_logic;
		slv_write_n : in std_logic;
		slv_data_in : in  std_logic_vector(31 downto 0);
		slv_data_out : out std_logic_vector(31 downto 0);
		slv_waitrequest_n : out std_logic -- 0: under process   1:process done, same ad wait_n
	);
end sys_max_id;

architecture rtl of sys_max_id is
	signal trigger, trigger_d1, trigger_d2, trigger_pls : std_logic;
	signal inc_num_int : std_logic_vector (10 downto 0);
	signal dec_num_int : std_logic_vector (10 downto 0);
	signal control_gui_int : std_logic_vector (15 downto 0);
	

begin

    inc_num     <= inc_num_int; 
    dec_num <= dec_num_int;
	 control_gui <= control_gui_int;

	process(clk, reset_n)begin
		if(reset_n = '0')then
			slv_data_out <= x"00000000";
		elsif(clk'event and clk = '1')then
			if(slv_en_n = '0' and slv_read_n = '0')then
				if(slv_address = "0000")then
					slv_data_out <= x"0000" & version;
				elsif(slv_address = "0001")then
					slv_data_out <= x"0000" & "00000" & inc_num_int;
				elsif(slv_address = "0010")then
					slv_data_out <= x"0000" & "00000" & dec_num_int;
				elsif(slv_address = "0011")then
					slv_data_out <= x"0000" & control_gui_int;
				else
					slv_data_out <= x"00000000";
				end if;
			end if;
		end if;
	end process;
	
	process(clk, reset_n)begin
		if(reset_n = '0')then
         inc_num_int <= "00000000000";
			dec_num_int <= "00000000000";
			control_gui_int <= x"0000";
		elsif(clk'event and clk = '1')then
			if(slv_en_n = '0' and slv_write_n = '0')then
				if(slv_address = "0001")then
				  if(clr_inc_num = '0') then
					 inc_num_int <= slv_data_in(10 downto 0);
				  else
				    inc_num_int <= "00000000000";
				  end if; 
				elsif(slv_address = "0010")then
				  if (clr_dec_num = '0') then
					 dec_num_int <= slv_data_in(10 downto 0);
				  else
				    dec_num_int <= "00000000000";
				  end if;
				elsif(slv_address = "0011")then
					 control_gui_int <= slv_data_in(15 downto 0);
				end if;
		    elsif (clr_inc_num = '1' or clr_dec_num = '1') then
				if(clr_inc_num = '1') then
				  inc_num_int <= "00000000000";	
				end if;
			   if(clr_dec_num = '1') then
				  dec_num_int <= "00000000000";	
				end if;	
			end if;
		end if;
	end process;
	
	process(clk, reset_n)begin
		if(reset_n = '0')then
			trigger <= '0';
		elsif(clk'event and clk = '1')then
			if(slv_en_n = '0' and (slv_read_n = '0' or slv_write_n = '0'))then
				trigger <= '1';
			else
				trigger <= '0';
			end if;
		end if;
	end process;
	
	process(clk, reset_n)begin
		if(reset_n = '0')then
			trigger_d1 <= '0';
			trigger_d2 <= '1';
		elsif(clk'event and clk = '1')then
			trigger_d2 <= trigger_d1; -- trigger_d1 <= trigger_d2;
			trigger_d1 <= not trigger;
		end if;
	end process;
	
	trigger_pls <= trigger and trigger_d2;
	
	
	process(clk, reset_n)begin
		if(reset_n = '0')then
			slv_waitrequest_n <= '1';
		elsif(clk'event and clk = '1')then
			if(trigger_pls = '1')then
				slv_waitrequest_n <= '1';
			elsif(slv_en_n = '1' or slv_read_n = '1')then
				slv_waitrequest_n <= '0';
			end if;
		end if;
	end process;
	
	
end rtl;
