// (C) 2001-2024 Intel Corporation. All rights reserved.
// Your use of Intel Corporation's design tools, logic functions and other 
// software and tools, and its AMPP partner logic functions, and any output 
// files from any of the foregoing (including device programming or simulation 
// files), and any associated documentation or information are expressly subject 
// to the terms and conditions of the Intel Program License Subscription 
// Agreement, Intel FPGA IP License Agreement, or other applicable 
// license agreement, including, without limitation, that your use is for the 
// sole purpose of programming logic devices manufactured by Intel and sold by 
// Intel or its authorized distributors.  Please refer to the applicable 
// agreement for further details.

#include "prbs_pattern_checker_regs.h"
#include "io.h"

// register write functions
void prbs_checker_set_payload_length (unsigned long base, unsigned long length)
{
  IOWR_32DIRECT(base, PRBS_CHECKER_PAYLOAD_LENGTH_REG, length);
}

void prbs_checker_enable_infinite_payload_length (unsigned long base)
{
  IOWR_8DIRECT(base, (PRBS_CHECKER_CONTROL_REG + PRBS_CHECKER_INFINITE_PAYLOAD_LENGTH_ENABLE_BYTE_OFFSET), 1);
}

void prbs_checker_disable_infinite_payload_length (unsigned long base)
{
  IOWR_8DIRECT(base, (PRBS_CHECKER_CONTROL_REG + PRBS_CHECKER_INFINITE_PAYLOAD_LENGTH_ENABLE_BYTE_OFFSET), 0);
}

void prbs_checker_seed_enable (unsigned long base)
{
  IOWR_8DIRECT(base, (PRBS_CHECKER_CONTROL_REG + PRBS_CHECKER_SEED_BYTE_OFFSET), 1);
}

void prbs_checker_enable_stop_on_failure (unsigned long base)
{
  IOWR_8DIRECT(base, (PRBS_CHECKER_CONTROL_REG + PRBS_CHECKER_STOP_ON_FAIL_BYTE_OFFSET), 1);
}

void prbs_checker_disable_stop_on_failure (unsigned long base)
{
  IOWR_8DIRECT(base, (PRBS_CHECKER_CONTROL_REG + PRBS_CHECKER_STOP_ON_FAIL_BYTE_OFFSET), 0);
}

void prbs_checker_enable_start (unsigned long base)
{
  IOWR_8DIRECT(base, (PRBS_CHECKER_CONTROL_REG + PRBS_CHECKER_RUN_BYTE_OFFSET), 1);
}

void prbs_checker_disable_start (unsigned long base)
{
  IOWR_8DIRECT(base, (PRBS_CHECKER_CONTROL_REG + PRBS_CHECKER_RUN_BYTE_OFFSET), 0);
}

void prbs_checker_set_polynomial (unsigned long base, unsigned char *polynomial, long polynomial_length)
{
  long i;
  
  for (i = 0; i < polynomial_length; i++)
  {
    IOWR_8DIRECT(base, (PRBS_CHECKER_POLYNOMIAL_31_0_REG + i), polynomial[i]);
  }

  for (i = polynomial_length; i < 16; i++)  // padding the other bytes for good measure, extra byte lanes that exceed the pattern data width will be ignored by the hardware
  {
    IOWR_8DIRECT(base, (PRBS_CHECKER_POLYNOMIAL_31_0_REG + i), 0);
  }
}



// register read functions
unsigned long prbs_checker_read_payload_length (unsigned long base)
{
  return (IORD_32DIRECT(base, PRBS_CHECKER_PAYLOAD_LENGTH_REG));
}

unsigned char prbs_checker_read_infinite_payload_length (unsigned long base)
{
  return (IORD_8DIRECT(base, (PRBS_CHECKER_CONTROL_REG + PRBS_CHECKER_INFINITE_PAYLOAD_LENGTH_ENABLE_BYTE_OFFSET)) & (PRBS_CHECKER_INFINITE_PAYLOAD_LENGTH_ENABLE_MASK >> PRBS_CHECKER_INFINITE_PAYLOAD_LENGTH_ENABLE_BIT_OFFSET));
}

unsigned char prbs_checker_read_stop_on_failure (unsigned long base)
{
  return (IORD_8DIRECT(base, (PRBS_CHECKER_CONTROL_REG + PRBS_CHECKER_STOP_ON_FAIL_BYTE_OFFSET)) & (PRBS_CHECKER_STOP_ON_FAIL_MASK >> PRBS_CHECKER_STOP_ON_FAIL_BIT_OFFSET));
}

unsigned char prbs_checker_read_start (unsigned long base)
{
  return (IORD_8DIRECT(base, (PRBS_CHECKER_CONTROL_REG + PRBS_CHECKER_RUN_BYTE_OFFSET)) & (PRBS_CHECKER_RUN_MASK >> PRBS_CHECKER_RUN_BIT_OFFSET));
}

unsigned char prbs_checker_read_failure_detected (unsigned long base)
{
  return (IORD_8DIRECT(base, (PRBS_CHECKER_STATUS_REG + PRBS_CHECKER_FAILURE_DETECTED_BYTE_OFFSET)) &  (PRBS_CHECKER_FAILURE_DETECTED_MASK >> PRBS_CHECKER_FAILURE_DETECTED_BIT_OFFSET));
}

void prbs_checker_read_polynomial (unsigned long base, unsigned char *polynomial, long polynomial_length)
{
  long i;
  
  for (i = 0; i < polynomial_length; i++)
  {
    *polynomial++ = IORD_8DIRECT(base, (PRBS_CHECKER_POLYNOMIAL_31_0_REG + i));
  }
  
}



// register clear function
void prbs_checker_clear_failure (unsigned long base)
{
  IOWR_8DIRECT(base, (PRBS_CHECKER_STATUS_REG + PRBS_CHECKER_FAILURE_DETECTED_BYTE_OFFSET), 1);
}


