/*******************************************************************************
* Copyright (C) 2001-2025 Altera Corporation
*
* This code and the related documents are Altera copyrighted materials and
* your use of them is governed by the express license under which they were
* provided to you ("License"). Unless the License provides otherwise, you may
* not use, modify, copy, publish, distribute, disclose, or transmit this
* code or the related documents without Altera's prior written permission.
* 
* This code and the related documents are provided as is, with no express
* or implied warranties other than those that are expressly stated in the
* License.
* 
*******************************************************************************/


`timescale 1 ps / 1 ps
module  bts_rdimm_2s1r(                        //2400mhz
        //Reset&Clock
      input  wire        fpga_resetn ,    // Reset, low active
      input  wire        clk_gpio_p_4,    // system clock, 100M
        //SGPIO for dipsw, leds
      input  wire        fpga_sgpio_sync,
      input  wire        fpga_sgpio_clk,
      input  wire        fpga_sgpi,    
      output wire        fpga_sgpo,
        //EMIF interface
      input  wire        DDR4_DIMM_2_REFCLKP,                          //                       ddr_ref_clk.clk
		output wire [1:0]  DDR4_DIMM_2_CKP,                 //                    emif_s10_0_mem.mem_ck
		output wire [1:0]  DDR4_DIMM_2_CKN,                 //                                  .mem_ck_n
		output wire [16:0] DDR4_DIMM_2_A,                    //                                  .mem_a
		output wire        DDR4_DIMM_2_ACTN,                 //                                  .mem_act_n
		output wire [1:0]  DDR4_DIMM_2_BA,                    //                                  .mem_ba
		output wire [1:0]  DDR4_DIMM_2_BG,                   //                                  .mem_bg		   // output wire        DDR4_DIMM_2_BG1,                   //                                  .mem_bg
		output wire [1:0]  DDR4_DIMM_2_CKE,                   //                                  .mem_cke
		output wire [1:0]  DDR4_DIMM_2_CSN,                  //                                  .mem_cs_n
		output wire [1:0]  DDR4_DIMM_2_ODT,                   //                                  .mem_odt
		output wire        DDR4_DIMM_2_RSTN,               //                                  .mem_reset_n
		output wire        DDR4_DIMM_2_PAR,                   //                                  .mem_par
		input  wire        DDR4_DIMM_2_ALERTN,               //                                  .mem_alert_n
		inout  wire [17:0] DDR4_DIMM_2_DQSP,               //                                  .mem_dqs
		inout  wire [17:0] DDR4_DIMM_2_DQSN,               //                                  .mem_dqs_n
		inout  wire [71:0] DDR4_DIMM_2_DQ,                //                                  .mem_dq               
	   input  wire        DDR4_DIMM_2_RZQ                   //                    emif_s10_0_oct.oct_rzqin//                    emif_s10_0_oct.oct_rzqin
        );
  
  reg  [26:0] heart_beat_cnt;
  wire        ninit_done;	
  wire        S_global_resetn;	  
  wire        sys_pll_locked;
  wire        clk_50m;
  wire[7:0]   fpga_led;
  wire        S_local_reset_done;
  wire        error_mon;
  wire        status_mon;
  
  assign S_global_resetn = !ninit_done && fpga_resetn;
	
  always @(posedge clk_50m or negedge S_global_resetn)
      if (!S_global_resetn)
          heart_beat_cnt <= 27'h0; //0x7ffffff
      else
          heart_beat_cnt <= heart_beat_cnt + 1'b1;	
		  
  reset_release reset_release_inst (
	.ninit_done(ninit_done)
	);
	
	assign fpga_led = {!error_mon, status_mon, !status_mon, !S_local_reset_done, 1'b1, !sys_pll_locked, 1'b1, heart_beat_cnt[26]};
	
 sys_pll sys_pll_inst (
		.rst      (!S_global_resetn),      //   input,  width = 1,   reset.reset
		.refclk   (clk_gpio_p_4),   //   input,  width = 1,  refclk.clk
		.locked   (sys_pll_locked),   //  output,  width = 1,  locked.export
		.outclk_0 (clk_50m)  //  output,  width = 1, outclk0.clk
	);
	
sgpio_slave sgpio_slave_inst(
    .i_rstn     (S_global_resetn ),
    .i_clk      (fpga_sgpio_clk  ),
    .i_sync     (fpga_sgpio_sync ),
    .i_mosi     (fpga_sgpi       ),
    .o_miso     (fpga_sgpo       ),
    .o_user_sw  (         ),
    .i_user_led (fpga_led        )
  );
//----------------------------------------------------------------------------------------------------------
// DDR4 example design
//----------------------------------------------------------------------------------------------------------
ed_synth ed_synth_inst (
      .clk_50m_clk                        (clk_50m         ), 
	   .global_reset_reset_n               (sys_pll_locked  ),
		.emif_fm_0_pll_ref_clk_clk          (DDR4_DIMM_2_REFCLKP),          //   input,   width = 1, emif_fm_0_pll_ref_clk.clk
		.emif_fm_0_oct_oct_rzqin            (DDR4_DIMM_2_RZQ),            //   input,   width = 1,         emif_fm_0_oct.oct_rzqin
		.emif_fm_0_mem_mem_ck               (DDR4_DIMM_2_CKP),               //  output,   width = 2,         emif_fm_0_mem.mem_ck
		.emif_fm_0_mem_mem_ck_n             (DDR4_DIMM_2_CKN),             //  output,   width = 2,                      .mem_ck_n
		.emif_fm_0_mem_mem_a                (DDR4_DIMM_2_A),                //  output,  width = 17,                      .mem_a
		.emif_fm_0_mem_mem_act_n            (DDR4_DIMM_2_ACTN),            //  output,   width = 1,                      .mem_act_n
		.emif_fm_0_mem_mem_ba               (DDR4_DIMM_2_BA),               //  output,   width = 2,                      .mem_ba
		.emif_fm_0_mem_mem_bg               (DDR4_DIMM_2_BG),               //  output,   width = 2,                      .mem_bg
		.emif_fm_0_mem_mem_cke              (DDR4_DIMM_2_CKE),              //  output,   width = 2,                      .mem_cke
		.emif_fm_0_mem_mem_cs_n             (DDR4_DIMM_2_CSN),             //  output,   width = 2,                      .mem_cs_n
		.emif_fm_0_mem_mem_odt              (DDR4_DIMM_2_ODT),              //  output,   width = 2,                      .mem_odt
		.emif_fm_0_mem_mem_reset_n          (DDR4_DIMM_2_RSTN),          //  output,   width = 1,                      .mem_reset_n
		.emif_fm_0_mem_mem_par              (DDR4_DIMM_2_PAR),              //  output,   width = 1,                      .mem_par
		.emif_fm_0_mem_mem_alert_n          (DDR4_DIMM_2_ALERTN),          //   input,   width = 1,                      .mem_alert_n
		.emif_fm_0_mem_mem_dqs              (DDR4_DIMM_2_DQSP),              //   inout,   width = 18,                      .mem_dqs
		.emif_fm_0_mem_mem_dqs_n            (DDR4_DIMM_2_DQSN),            //   inout,   width = 18,                      .mem_dqs_n
		.emif_fm_0_mem_mem_dq               (DDR4_DIMM_2_DQ),               //   inout,  width = 72,                      .mem_dq
		.local_reset_req_local_reset_req    (sys_pll_locked),
	   .local_reset_status_local_reset_done (S_local_reset_done),
	   .master_driver_msgdma_0_error_mon_export (error_mon),
	   .master_driver_msgdma_0_status_mon_export(status_mon)
	);
endmodule