/*******************************************************************************
* Copyright (C) 2001-2025 Altera Corporation
*
* This code and the related documents are Altera copyrighted materials and
* your use of them is governed by the express license under which they were
* provided to you ("License"). Unless the License provides otherwise, you may
* not use, modify, copy, publish, distribute, disclose, or transmit this
* code or the related documents without Altera's prior written permission.
* 
* This code and the related documents are provided as is, with no express
* or implied warranties other than those that are expressly stated in the
* License.
* 
*******************************************************************************/


`timescale 1ns / 100ps
module  bts_xcvr (
        //Reset&Clock
        input  wire        fpga_resetn    , // Reset, low active
        input  wire        clk_gpio_p_4     , // System clock, 100MHz
        input  wire        refclk_fgt12Cch2_p  , // fmc reference clock 156.25MHz
		
		//SGPIO for dipsw, leds
        input  wire        fpga_sgpio_sync,
        input  wire        fpga_sgpio_clk ,
        input  wire        fpga_sgpi      ,    
        output wire        fpga_sgpo      ,
        //XCVR channels
        input  wire [15:0]  fmc_rx_p      , 
        input  wire [15:0]  fmc_rx_n      , 
        output wire [15:0]  fmc_tx_p      , 
        output wire [15:0]  fmc_tx_n      ,
        //COMS Interface		      
        //input             falan0             , // input,  lvds/cmos loopback test is not supported, input clock from loopback card
        //input             falap0             , // input,  lvds/cmos loopback test is not supported, input clock from loopback card
        //output            falan1             , // output, lvds/cmos loopback test is not supported, output clock to loopback card
        //output            falap1             , // output, lvds/cmos loopback test is not supported, output clock to loopback card      
        input  wire         falan2             ,
        input  wire         falap2             ,
        output wire         falan3             ,
        output wire         falap3             ,
        input  wire         falan4             ,
        input  wire         falap4             ,
        input  wire         falan5             ,
        input  wire         falap5             ,
        output wire         falan6             ,
        output wire         falap6             ,
        input  wire         falan7             ,
        input  wire         falap7             ,
        output wire         falan8             ,
        output wire         falap8             ,
        input  wire         falan9             ,
        input  wire         falap9             ,
        output wire         falan10            ,
        output wire         falap10            ,
        input  wire         falan11            ,
        input  wire         falap11            ,
        output wire         falan12            ,
        output wire         falap12            ,
        input  wire         falan13            ,
        input  wire         falap13            ,
        output wire         falan14            ,
        output wire         falap14            ,
        input  wire         falan15            ,
        input  wire         falap15            ,
        output wire         falan16            ,
        output wire         falap16            ,
        input  wire         falan17            ,
        input  wire         falap17            ,
        output wire         falan18            ,
        output wire         falap18            ,
        input  wire         falan19            ,
        input  wire         falap19            ,
        output wire         falan20            ,
        output wire         falap20            ,
        input  wire         falan21            ,
        input  wire         falap21            ,
        output wire         falan22            ,
        output wire         falap22            ,
        input  wire         falan23            ,
        input  wire         falap23            ,
        input  wire         falan24            ,
        input  wire         falap24            ,
        output wire         falan25            ,
        output wire         falap25            ,
        input  wire         falan26            ,
        input  wire         falap26            ,
        output wire         falan27            ,
        output wire         falap27            ,
        input  wire         falan28            ,
        input  wire         falap28            ,
        output wire         falan29            ,
        output wire         falap29            ,
        input  wire         falan30            ,
        input  wire         falap30            ,
        output wire         falan31            ,
        output wire         falap31            ,
        output wire         falan32            ,
        output wire         falap32            ,
        output wire         falan33            ,
        output wire         falap33                 	
        );
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Signal definitions
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
wire          ninit_done/* synthesis keep */;
wire          S_global_resetn/* synthesis keep */;
reg  [26:0]   heart_beat_cnt/* synthesis keep */;
wire          clk_50m     ; // System clock, 50MHz
wire  [7:0]   fpga_led;
wire [31:0]   fmc_cmos_la_tx_parallel_data;
wire [31:0]   fmc_cmos_la_rx_parallel_data;
wire [31:0]   fmc_cmos_la_parallel_debug;
wire          fmc_cmos_la_loopback_en;
 sys_pll sys_pll_inst (
		.rst      (!S_global_resetn),      //   input,  width = 1,   reset.reset
		.refclk   (clk_gpio_p_4),   //   input,  width = 1,  refclk.clk
		.locked   ( ),   //  output,  width = 1,  locked.export
		.outclk_0 (clk_50m)  //  output,  width = 1, outclk0.clk
	);
	
//----------------------------------------------------------------------------------------------------------
// Intel Agilex Reset Release
//----------------------------------------------------------------------------------------------------------
reset_release reset_release_inst 
              (
              .ninit_done (ninit_done)  // ninit_done.ninit_done
              );
assign S_global_resetn = !ninit_done & fpga_resetn;
  sgpio_slave sgpio_slave_inst(
    .i_rstn     (S_global_resetn ),
    .i_clk      (fpga_sgpio_clk  ),
    .i_sync     (fpga_sgpio_sync ),
    .i_mosi     (fpga_sgpi       ),
    .o_miso     (fpga_sgpo       ),
    .o_user_sw  (         ),
    .i_user_led (fpga_led        )
  );
assign fpga_led = {5'hf,!heart_beat_cnt[25], ninit_done, heart_beat_cnt[26]};
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Heart-beat indicate
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
always @(posedge clk_50m or negedge S_global_resetn)
    if (!S_global_resetn)
        heart_beat_cnt <= 27'h0; //0x7FFFFFF
    else
        heart_beat_cnt <= heart_beat_cnt + 1'b1;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//CMOS interface
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
assign {
        falap3,   
        falan3,
        falap6,
        falan6,
        falap8,
        falan8,
        falap10,
        falan10,
        falap12,
        falan12,
        falap14,
        falan14,
        falap16,
        falan16,
        falap18,
        falan18,
        falap20,
        falan20,
        falap22,
        falan22,
        falap25,
        falan25,
        falap27,
        falan27,
        falap29,
        falan29,
        falap31,
        falan31,
        falap33,
        falan33,
        falap32,
        falan32  // bit32
        } = fmc_cmos_la_loopback_en ? fmc_cmos_la_parallel_debug : fmc_cmos_la_tx_parallel_data;   
assign	fmc_cmos_la_rx_parallel_data = fmc_cmos_la_loopback_en ? fmc_cmos_la_tx_parallel_data :	
                                                                    {
                                                                    falap2,         
                                                                    falan2,
                                                                    falap4,
                                                                    falan4,
                                                                    falap5,
                                                                    falan5,
                                                                    falap7,
                                                                    falan7,
                                                                    falap9,
                                                                    falan9,
                                                                    falap11,
                                                                    falan11,
                                                                    falap13,
                                                                    falan13,
                                                                    falap15,
                                                                    falan15,
                                                                    falap17,
                                                                    falan17,
                                                                    falap19,
                                                                    falan19,
                                                                    falap21,
                                                                    falan21,
                                                                    falap23,
                                                                    falan23,
                                                                    falap24,
                                                                    falan24,
                                                                    falap26,
                                                                    falan26,
                                                                    falap28,
                                                                    falan28,
                                                                    falap30,
                                                                    falan30        // bit32
                                                                   };
																   
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//XCVR system Qsys module
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
q_sys   q_sys_u0 (
        .clk_50_clk                                               (clk_50m       ), //  input,  width = 1,                                              clk.clk
        .reset_50_reset_n                                         (S_global_resetn        ),
		.clk_100_clk                                              (clk_gpio_p_4),
		.reset_100_reset_n                                        (S_global_resetn        ), //input,  width = 1,                                            reset.reset_n
        .systemclk_f_0_refclk_fgt_in_refclk_fgt_2                 (refclk_fgt12Cch2_p   ), //                     systemclk_f_0_refclk_fgt.in_refclk_fgt_0
        .fmc_cmos_test_0_nativephy_loopback_cont_0_rx_seriallpbken_rx_seriallpbken  (fmc_cmos_la_loopback_en),  //  output,   width = 1, fmc_cmos_test_0_nativephy_loopback_cont_0_rx_seriallpbken.rx_seriallpbken
		.fmc_cmos_test_0_pio_0_external_connection_export                           (fmc_cmos_la_parallel_debug),                           //  output,  width = 32,                 fmc_cmos_test_0_pio_0_external_connection.export
		.fmc_cmos_test_0_xcvr_st_converter_cmos_0_tx_parallel_data_tx_parallel_data (fmc_cmos_la_tx_parallel_data), //  output,  width = 32, fmc_cmos_test_0_xcvr_st_converter_cmos_0_tx_parallel_data.tx_parallel_data
		.fmc_cmos_test_0_xcvr_st_converter_cmos_0_rx_parallel_data_rx_parallel_data (fmc_cmos_la_rx_parallel_data), //   input,  width = 32, fmc_cmos_test_0_xcvr_st_converter_cmos_0_rx_parallel_data.rx_parallel_data
		.ftile_xcvr_test_0_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[0]      ), //     ftile_xcvr_test_0_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_0_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[0]      ), //   ftile_xcvr_test_0_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_0_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[0]      ), //     ftile_xcvr_test_0_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_0_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[0]      ), //   ftile_xcvr_test_0_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_1_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[1]      ), //     ftile_xcvr_test_1_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_1_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[1]      ), //   ftile_xcvr_test_1_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_1_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[1]      ), //     ftile_xcvr_test_1_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_1_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[1]      ), //   ftile_xcvr_test_1_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_2_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[2]      ), //     ftile_xcvr_test_2_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_2_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[2]      ), //   ftile_xcvr_test_2_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_2_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[2]      ), //     ftile_xcvr_test_2_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_2_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[2]      ), //   ftile_xcvr_test_2_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_3_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[3]      ), //     ftile_xcvr_test_3_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_3_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[3]      ), //   ftile_xcvr_test_3_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_3_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[3]      ), //     ftile_xcvr_test_3_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_3_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[3]      ),  //   ftile_xcvr_test_3_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_4_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[4]      ), //     ftile_xcvr_test_4_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_4_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[4]      ), //   ftile_xcvr_test_4_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_4_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[4]      ), //     ftile_xcvr_test_4_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_4_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[4]      ), //   ftile_xcvr_test_4_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_5_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[5]      ), //     ftile_xcvr_test_5_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_5_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[5]      ), //   ftile_xcvr_test_5_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_5_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[5]      ), //     ftile_xcvr_test_5_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_5_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[5]      ), //   ftile_xcvr_test_5_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_6_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[6]      ), //     ftile_xcvr_test_6_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_6_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[6]      ), //   ftile_xcvr_test_6_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_6_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[6]      ), //     ftile_xcvr_test_6_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_6_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[6]      ), //   ftile_xcvr_test_6_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_7_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[7]      ), //     ftile_xcvr_test_7_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_7_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[7]      ), //   ftile_xcvr_test_7_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_7_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[7]      ), //     ftile_xcvr_test_7_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_7_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[7]      ),  //   ftile_xcvr_test_7_directphy_f_0_rx_serial_data_n.rx_serial_data_n
		.ftile_xcvr_test_8_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[8]      ), //     ftile_xcvr_test_8_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_8_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[8]      ), //   ftile_xcvr_test_8_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_8_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[8]      ), //     ftile_xcvr_test_8_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_8_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[8]      ), //   ftile_xcvr_test_8_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_9_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[9]      ), //     ftile_xcvr_test_9_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_9_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[9]      ), //   ftile_xcvr_test_9_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_9_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[9]      ), //     ftile_xcvr_test_9_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_9_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[9]      ), //   ftile_xcvr_test_9_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_10_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[10]      ), //     ftile_xcvr_test_10_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_10_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[10]      ), //   ftile_xcvr_test_10_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_10_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[10]      ), //     ftile_xcvr_test_10_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_10_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[10]      ), //   ftile_xcvr_test_10_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_11_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[11]      ), //     ftile_xcvr_test_11_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_11_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[11]      ), //   ftile_xcvr_test_11_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_11_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[11]      ), //     ftile_xcvr_test_11_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_11_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[11]      ),  //   ftile_xcvr_test_11_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_12_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[12]      ), //     ftile_xcvr_test_12_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_12_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[12]      ), //   ftile_xcvr_test_12_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_12_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[12]      ), //     ftile_xcvr_test_12_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_12_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[12]      ), //   ftile_xcvr_test_12_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_13_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[13]      ), //     ftile_xcvr_test_13_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_13_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[13]      ), //   ftile_xcvr_test_13_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_13_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[13]      ), //     ftile_xcvr_test_13_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_13_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[13]      ), //   ftile_xcvr_test_13_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_14_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[14]      ), //     ftile_xcvr_test_14_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_14_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[14]      ), //   ftile_xcvr_test_14_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_14_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[14]      ), //     ftile_xcvr_test_14_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_14_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[14]      ), //   ftile_xcvr_test_14_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_15_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[15]      ), //     ftile_xcvr_test_15_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_15_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[15]      ), //   ftile_xcvr_test_15_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_15_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[15]      ), //     ftile_xcvr_test_15_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_15_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[15]      )  //   ftile_xcvr_test_15_directphy_f_0_rx_serial_data_n.rx_serial_data_n
    );
endmodule
