/*******************************************************************************
* Copyright (C) 2001-2025 Altera Corporation
*
* This code and the related documents are Altera copyrighted materials and
* your use of them is governed by the express license under which they were
* provided to you ("License"). Unless the License provides otherwise, you may
* not use, modify, copy, publish, distribute, disclose, or transmit this
* code or the related documents without Altera's prior written permission.
* 
* This code and the related documents are provided as is, with no express
* or implied warranties other than those that are expressly stated in the
* License.
* 
*******************************************************************************/


`timescale 1ns / 100ps
module  bts_xcvr (
        //Reset&Clock
        input  wire        fpga_resetn    , // Reset, low active
        input  wire        clk_gpio_p_4     , // System clock, 100MHz
        input  wire        refclk_fgt13Ach4_p    , // MXPM reference clock 156.25MHz 
		
		//SGPIO for dipsw, leds
        input  wire        fpga_sgpio_sync,
        input  wire        fpga_sgpio_clk ,
        input  wire        fpga_sgpi      ,    
        output wire        fpga_sgpo      ,
        //MXPM XCVR channels
        input  wire [3:0]  mxpm_rx_p          , // MXPM RX P
        input  wire [3:0]  mxpm_rx_n          , // MXPM RX N
        output wire [3:0]  mxpm_tx_p          , // MXPM TX P
        output wire [3:0]  mxpm_tx_n            // MXPM TX N
        );
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Signal definitions
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
wire          ninit_done/* synthesis keep */;
wire          S_global_resetn/* synthesis keep */;
reg  [26:0]   heart_beat_cnt/* synthesis keep */;
wire          clk_50m     ; // System clock, 50MHz
wire  [7:0]   fpga_led;
 sys_pll sys_pll_inst (
		.rst      (!S_global_resetn),      //   input,  width = 1,   reset.reset
		.refclk   (clk_gpio_p_4),   //   input,  width = 1,  refclk.clk
		.locked   ( ),   //  output,  width = 1,  locked.export
		.outclk_0 (clk_50m)  //  output,  width = 1, outclk0.clk
	);
	
//----------------------------------------------------------------------------------------------------------
// Intel Agilex Reset Release
//----------------------------------------------------------------------------------------------------------
reset_release reset_release_inst 
              (
              .ninit_done (ninit_done)  // ninit_done.ninit_done
              );
assign S_global_resetn = !ninit_done & fpga_resetn;
  sgpio_slave sgpio_slave_inst(
    .i_rstn     (S_global_resetn ),
    .i_clk      (fpga_sgpio_clk  ),
    .i_sync     (fpga_sgpio_sync ),
    .i_mosi     (fpga_sgpi       ),
    .o_miso     (fpga_sgpo       ),
    .o_user_sw  (         ),
    .i_user_led (fpga_led        )
  );
assign fpga_led = {5'hf,!heart_beat_cnt[25], ninit_done, heart_beat_cnt[26]};
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Heart-beat indicate
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
always @(posedge clk_50m or negedge S_global_resetn)
    if (!S_global_resetn)
        heart_beat_cnt <= 27'h0; //0x7FFFFFF
    else
        heart_beat_cnt <= heart_beat_cnt + 1'b1;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//XCVR system Qsys module
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
q_sys   q_sys_u0 (
        .clk_100_clk                                                  (clk_gpio_p_4       ), //                                      clk_100.clk
        .reset_100_reset_n                                            (S_global_resetn        ), //                                    reset_100.reset_n
        .clk_50_clk                                                   (clk_50m    ), //                                       clk_50.clk
        .reset_50_reset_n                                             (S_global_resetn        ), //                                     reset_50.reset_n
        .systemclk_f_0_refclk_fgt_in_refclk_fgt_4                          (refclk_fgt13Ach4_p   ), //  systemclk_f_0_refclk_fgt.in_refclk_fgt_4
        .ftile_xcvr_test_0_directphy_f_0_tx_serial_data_tx_serial_data     (mxpm_tx_p[0]      ),   
        .ftile_xcvr_test_0_directphy_f_0_tx_serial_data_n_tx_serial_data_n (mxpm_tx_n[0]      ),  
        .ftile_xcvr_test_0_directphy_f_0_rx_serial_data_rx_serial_data     (mxpm_rx_p[0]      ),  
        .ftile_xcvr_test_0_directphy_f_0_rx_serial_data_n_rx_serial_data_n (mxpm_rx_n[0]      ),  
        .ftile_xcvr_test_1_directphy_f_0_tx_serial_data_tx_serial_data     (mxpm_tx_p[1]      ),  
        .ftile_xcvr_test_1_directphy_f_0_tx_serial_data_n_tx_serial_data_n (mxpm_tx_n[1]      ),  
        .ftile_xcvr_test_1_directphy_f_0_rx_serial_data_rx_serial_data     (mxpm_rx_p[1]      ),  
        .ftile_xcvr_test_1_directphy_f_0_rx_serial_data_n_rx_serial_data_n (mxpm_rx_n[1]      ),  
        .ftile_xcvr_test_2_directphy_f_0_tx_serial_data_tx_serial_data     (mxpm_tx_p[2]      ), 
		.ftile_xcvr_test_2_directphy_f_0_tx_serial_data_n_tx_serial_data_n (mxpm_tx_n[2]      ),
        .ftile_xcvr_test_2_directphy_f_0_rx_serial_data_rx_serial_data     (mxpm_rx_p[2]      ),
        .ftile_xcvr_test_2_directphy_f_0_rx_serial_data_n_rx_serial_data_n (mxpm_rx_n[2]      ),
        .ftile_xcvr_test_3_directphy_f_0_tx_serial_data_tx_serial_data     (mxpm_tx_p[3]      ),
        .ftile_xcvr_test_3_directphy_f_0_tx_serial_data_n_tx_serial_data_n (mxpm_tx_n[3]      ),
        .ftile_xcvr_test_3_directphy_f_0_rx_serial_data_rx_serial_data     (mxpm_rx_p[3]      ),
        .ftile_xcvr_test_3_directphy_f_0_rx_serial_data_n_rx_serial_data_n (mxpm_rx_n[3]      )
		);
endmodule
