/*******************************************************************************
* Copyright (C) 2001-2025 Altera Corporation
*
* This code and the related documents are Altera copyrighted materials and
* your use of them is governed by the express license under which they were
* provided to you ("License"). Unless the License provides otherwise, you may
* not use, modify, copy, publish, distribute, disclose, or transmit this
* code or the related documents without Altera's prior written permission.
* 
* This code and the related documents are provided as is, with no express
* or implied warranties other than those that are expressly stated in the
* License.
* 
*******************************************************************************/


`timescale 1ns / 100ps
module  bts_xcvr (
        //Reset&Clock
        input  wire        clk_gpio_p_4,    // system clock, 100M
        input  wire        fpga_resetn ,    //sysmax_pb[1] to trigger hard reset
       
	    input  wire        in_refclk_fgt_13C,
        input  wire        in_refclk_fht_13C,
		input  wire        in_refclk_fgt_13A,
        input  wire        in_refclk_fht_13A,
		
		//SGPIO for dipsw, leds
        input  wire        fpga_sgpio_sync,
        input  wire        fpga_sgpio_clk,
        input  wire        fpga_sgpi,    
        output wire        fpga_sgpo,
        //XCVR channels
        input  wire [7:0]  qsfpdd800_rx_p      , 
        input  wire [7:0]  qsfpdd800_rx_n      , 
        output wire [7:0]  qsfpdd800_tx_p      , 
        output wire [7:0]  qsfpdd800_tx_n       
        );
  wire       clk_50m;
  wire       ninit_done;
  wire       global_resetn;
  reg [26:0] heart_beat_cnt;
  wire [7:0] fpga_led;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Signal definitions
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 reset_release reset_release (
	.ninit_done(ninit_done)
	); 
	
 sys_pll sys_pll_inst (
		.rst      (!global_resetn),      //   input,  width = 1,   reset.reset
		.refclk   (clk_gpio_p_4),   //   input,  width = 1,  refclk.clk
		.locked   ( ),   //  output,  width = 1,  locked.export
		.outclk_0 (clk_50m)  //  output,  width = 1, outclk0.clk
	);
	
assign global_resetn = !ninit_done && fpga_resetn; //nINIT_DONE is high until the entire device enters user mode
always @(posedge clk_50m or negedge global_resetn)
    if (!global_resetn)
        heart_beat_cnt <= 27'h0; //0x7ffffff
    else
        heart_beat_cnt <= heart_beat_cnt + 1'b1;
		
	
sgpio_slave sgpio_slave_inst(
    .i_rstn     (global_resetn ),
    .i_clk      (fpga_sgpio_clk  ),
    .i_sync     (fpga_sgpio_sync ),
    .i_mosi     (fpga_sgpi       ),
    .o_miso     (fpga_sgpo       ),
    .o_user_sw  (         ),
    .i_user_led (fpga_led        )
  );
  
assign fpga_led = {5'hf,!heart_beat_cnt[25], ninit_done, heart_beat_cnt[26]};
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//XCVR system Qsys module
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	q_sys u0 (
		.clk_50_clk                                                        (clk_50m),                                                        //   input,  width = 1,                                           clk_50.clk
		.reset_50_reset_n                                                  (global_resetn),                                                  //   input,  width = 1,                                         reset_50.reset_n
		.systemclk_f_0_refclk_fgt_in_refclk_fgt_4                          (in_refclk_fgt_13C),                          //   input,  width = 1,                         systemclk_f_0_refclk_fgt.in_refclk_fgt_4
		.systemclk_f_0_refclk_fht_in_refclk_fht_0                          (in_refclk_fht_13C),                          //   input,  width = 1,                         systemclk_f_0_refclk_fht.in_refclk_fht_0
		.systemclk_f_1_refclk_fgt_in_refclk_fgt_4                          (in_refclk_fgt_13A),                          //   input,  width = 1,                         systemclk_f_1_refclk_fgt.in_refclk_fgt_4
		.systemclk_f_1_refclk_fht_in_refclk_fht_0                          (in_refclk_fht_13A),                          //   input,  width = 1,                         systemclk_f_1_refclk_fht.in_refclk_fht_0		
		.ftile_xcvr_test_0_directphy_f_0_tx_serial_data_tx_serial_data     (qsfpdd800_tx_p[0]),     //  output,  width = 1,   ftile_xcvr_test_0_directphy_f_0_tx_serial_data.tx_serial_data
		.ftile_xcvr_test_0_directphy_f_0_tx_serial_data_n_tx_serial_data_n (qsfpdd800_tx_n[0]), //  output,  width = 1, ftile_xcvr_test_0_directphy_f_0_tx_serial_data_n.tx_serial_data_n
		.ftile_xcvr_test_0_directphy_f_0_rx_serial_data_rx_serial_data     (qsfpdd800_rx_p[0]),     //   input,  width = 1,   ftile_xcvr_test_0_directphy_f_0_rx_serial_data.rx_serial_data
		.ftile_xcvr_test_0_directphy_f_0_rx_serial_data_n_rx_serial_data_n (qsfpdd800_rx_n[0]), //   input,  width = 1, ftile_xcvr_test_0_directphy_f_0_rx_serial_data_n.rx_serial_data_n
		.ftile_xcvr_test_1_directphy_f_0_tx_serial_data_tx_serial_data     (qsfpdd800_tx_p[1]),     //  output,  width = 1,   ftile_xcvr_test_1_directphy_f_0_tx_serial_data.tx_serial_data
		.ftile_xcvr_test_1_directphy_f_0_tx_serial_data_n_tx_serial_data_n (qsfpdd800_tx_n[1]), //  output,  width = 1, ftile_xcvr_test_1_directphy_f_0_tx_serial_data_n.tx_serial_data_n
		.ftile_xcvr_test_1_directphy_f_0_rx_serial_data_rx_serial_data     (qsfpdd800_rx_p[1]),     //   input,  width = 1,   ftile_xcvr_test_1_directphy_f_0_rx_serial_data.rx_serial_data
		.ftile_xcvr_test_1_directphy_f_0_rx_serial_data_n_rx_serial_data_n (qsfpdd800_rx_n[1]), //   input,  width = 1, ftile_xcvr_test_1_directphy_f_0_rx_serial_data_n.rx_serial_data_n
		.ftile_xcvr_test_2_directphy_f_0_tx_serial_data_tx_serial_data     (qsfpdd800_tx_p[2]),     //  output,  width = 1,   ftile_xcvr_test_2_directphy_f_0_tx_serial_data.tx_serial_data
		.ftile_xcvr_test_2_directphy_f_0_tx_serial_data_n_tx_serial_data_n (qsfpdd800_tx_n[2]), //  output,  width = 1, ftile_xcvr_test_2_directphy_f_0_tx_serial_data_n.tx_serial_data_n
		.ftile_xcvr_test_2_directphy_f_0_rx_serial_data_rx_serial_data     (qsfpdd800_rx_p[2]),     //   input,  width = 1,   ftile_xcvr_test_2_directphy_f_0_rx_serial_data.rx_serial_data
		.ftile_xcvr_test_2_directphy_f_0_rx_serial_data_n_rx_serial_data_n (qsfpdd800_rx_n[2]), //   input,  width = 1, ftile_xcvr_test_2_directphy_f_0_rx_serial_data_n.rx_serial_data_n
		.ftile_xcvr_test_3_directphy_f_0_tx_serial_data_tx_serial_data     (qsfpdd800_tx_p[3]),     //  output,  width = 1,   ftile_xcvr_test_3_directphy_f_0_tx_serial_data.tx_serial_data
		.ftile_xcvr_test_3_directphy_f_0_tx_serial_data_n_tx_serial_data_n (qsfpdd800_tx_n[3]), //  output,  width = 1, ftile_xcvr_test_3_directphy_f_0_tx_serial_data_n.tx_serial_data_n
		.ftile_xcvr_test_3_directphy_f_0_rx_serial_data_rx_serial_data     (qsfpdd800_rx_p[3]),     //   input,  width = 1,   ftile_xcvr_test_3_directphy_f_0_rx_serial_data.rx_serial_data
		.ftile_xcvr_test_3_directphy_f_0_rx_serial_data_n_rx_serial_data_n (qsfpdd800_rx_n[3]),  //   input,  width = 1, ftile_xcvr_test_3_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_4_directphy_f_0_tx_serial_data_tx_serial_data     (qsfpdd800_tx_p[4]),     //  output,  width = 1,   ftile_xcvr_test_4_directphy_f_0_tx_serial_data.tx_serial_data
		.ftile_xcvr_test_4_directphy_f_0_tx_serial_data_n_tx_serial_data_n (qsfpdd800_tx_n[4]), //  output,  width = 1, ftile_xcvr_test_4_directphy_f_0_tx_serial_data_n.tx_serial_data_n
		.ftile_xcvr_test_4_directphy_f_0_rx_serial_data_rx_serial_data     (qsfpdd800_rx_p[4]),     //   input,  width = 1,   ftile_xcvr_test_4_directphy_f_0_rx_serial_data.rx_serial_data
		.ftile_xcvr_test_4_directphy_f_0_rx_serial_data_n_rx_serial_data_n (qsfpdd800_rx_n[4]), //   input,  width = 1, ftile_xcvr_test_4_directphy_f_0_rx_serial_data_n.rx_serial_data_n
		.ftile_xcvr_test_5_directphy_f_0_tx_serial_data_tx_serial_data     (qsfpdd800_tx_p[5]),     //  output,  width = 1,   ftile_xcvr_test_5_directphy_f_0_tx_serial_data.tx_serial_data
		.ftile_xcvr_test_5_directphy_f_0_tx_serial_data_n_tx_serial_data_n (qsfpdd800_tx_n[5]), //  output,  width = 1, ftile_xcvr_test_5_directphy_f_0_tx_serial_data_n.tx_serial_data_n
		.ftile_xcvr_test_5_directphy_f_0_rx_serial_data_rx_serial_data     (qsfpdd800_rx_p[5]),     //   input,  width = 1,   ftile_xcvr_test_5_directphy_f_0_rx_serial_data.rx_serial_data
		.ftile_xcvr_test_5_directphy_f_0_rx_serial_data_n_rx_serial_data_n (qsfpdd800_rx_n[5]), //   input,  width = 1, ftile_xcvr_test_5_directphy_f_0_rx_serial_data_n.rx_serial_data_n
		.ftile_xcvr_test_6_directphy_f_0_tx_serial_data_tx_serial_data     (qsfpdd800_tx_p[6]),     //  output,  width = 1,   ftile_xcvr_test_6_directphy_f_0_tx_serial_data.tx_serial_data
		.ftile_xcvr_test_6_directphy_f_0_tx_serial_data_n_tx_serial_data_n (qsfpdd800_tx_n[6]), //  output,  width = 1, ftile_xcvr_test_6_directphy_f_0_tx_serial_data_n.tx_serial_data_n
		.ftile_xcvr_test_6_directphy_f_0_rx_serial_data_rx_serial_data     (qsfpdd800_rx_p[6]),     //   input,  width = 1,   ftile_xcvr_test_6_directphy_f_0_rx_serial_data.rx_serial_data
		.ftile_xcvr_test_6_directphy_f_0_rx_serial_data_n_rx_serial_data_n (qsfpdd800_rx_n[6]), //   input,  width = 1, ftile_xcvr_test_6_directphy_f_0_rx_serial_data_n.rx_serial_data_n
		.ftile_xcvr_test_7_directphy_f_0_tx_serial_data_tx_serial_data     (qsfpdd800_tx_p[7]),     //  output,  width = 1,   ftile_xcvr_test_7_directphy_f_0_tx_serial_data.tx_serial_data
		.ftile_xcvr_test_7_directphy_f_0_tx_serial_data_n_tx_serial_data_n (qsfpdd800_tx_n[7]), //  output,  width = 1, ftile_xcvr_test_7_directphy_f_0_tx_serial_data_n.tx_serial_data_n
		.ftile_xcvr_test_7_directphy_f_0_rx_serial_data_rx_serial_data     (qsfpdd800_rx_p[7]),     //   input,  width = 1,   ftile_xcvr_test_7_directphy_f_0_rx_serial_data.rx_serial_data
		.ftile_xcvr_test_7_directphy_f_0_rx_serial_data_n_rx_serial_data_n (qsfpdd800_rx_n[7])  //   input,  width = 1, ftile_xcvr_test_7_directphy_f_0_rx_serial_data_n.rx_serial_data_n
	);
	
endmodule
