// (C) 2001-2024 Intel Corporation. All rights reserved.
// Your use of Intel Corporation's design tools, logic functions and other 
// software and tools, and its AMPP partner logic functions, and any output 
// files from any of the foregoing (including device programming or simulation 
// files), and any associated documentation or information are expressly subject 
// to the terms and conditions of the Intel Program License Subscription 
// Agreement, Intel FPGA IP License Agreement, or other applicable 
// license agreement, including, without limitation, that your use is for the 
// sole purpose of programming logic devices manufactured by Intel and sold by 
// Intel or its authorized distributors.  Please refer to the applicable 
// agreement for further details.


`timescale 1ns / 100ps
module  bts_xcvr (
        //Reset&Clock
        input  wire        fpga_resetn    , // Reset, low active
        input  wire        clk_gpio_p_4     , // System clock, 100MHz
        input  wire        refclk_fgt12Ach2_p  , // fmc reference clock 156.25MHz
		
		//SGPIO for dipsw, leds
        input  wire        fpga_sgpio_sync,
        input  wire        fpga_sgpio_clk ,
        input  wire        fpga_sgpi      ,    
        output wire        fpga_sgpo      ,
        //XCVR channels
        input  wire [15:0]  fmc_rx_p      , 
        input  wire [15:0]  fmc_rx_n      , 
        output wire [15:0]  fmc_tx_p      , 
        output wire [15:0]  fmc_tx_n      ,
        //COMS Interface		      
        //input             fblan0             , // input,  lvds/cmos loopback test is not supported, input clock from loopback card
        //input             fblap0             , // input,  lvds/cmos loopback test is not supported, input clock from loopback card
        //output            fblan1             , // output, lvds/cmos loopback test is not supported, output clock to loopback card
        //output            fblap1             , // output, lvds/cmos loopback test is not supported, output clock to loopback card      
        input  wire         fblan2             ,
        input  wire         fblap2             ,
        output wire         fblan3             ,
        output wire         fblap3             ,
        input  wire         fblan4             ,
        input  wire         fblap4             ,
        input  wire         fblan5             ,
        input  wire         fblap5             ,
        output wire         fblan6             ,
        output wire         fblap6             ,
        input  wire         fblan7             ,
        input  wire         fblap7             ,
        output wire         fblan8             ,
        output wire         fblap8             ,
        input  wire         fblan9             ,
        input  wire         fblap9             ,
        output wire         fblan10            ,
        output wire         fblap10            ,
        input  wire         fblan11            ,
        input  wire         fblap11            ,
        output wire         fblan12            ,
        output wire         fblap12            ,
        input  wire         fblan13            ,
        input  wire         fblap13            ,
        output wire         fblan14            ,
        output wire         fblap14            ,
        input  wire         fblan15            ,
        input  wire         fblap15            ,
        output wire         fblan16            ,
        output wire         fblap16            ,
        input  wire         fblan17            ,
        input  wire         fblap17            ,
        output wire         fblan18            ,
        output wire         fblap18            ,
        input  wire         fblan19            ,
        input  wire         fblap19            ,
        output wire         fblan20            ,
        output wire         fblap20            ,
        input  wire         fblan21            ,
        input  wire         fblap21            ,
        output wire         fblan22            ,
        output wire         fblap22            ,
        input  wire         fblan23            ,
        input  wire         fblap23            ,
        input  wire         fblan24            ,
        input  wire         fblap24            ,
        output wire         fblan25            ,
        output wire         fblap25            ,
        input  wire         fblan26            ,
        input  wire         fblap26            ,
        output wire         fblan27            ,
        output wire         fblap27            ,
        input  wire         fblan28            ,
        input  wire         fblap28            ,
        output wire         fblan29            ,
        output wire         fblap29            ,
        input  wire         fblan30            ,
        input  wire         fblap30            ,
        output wire         fblan31            ,
        output wire         fblap31            ,
        output wire         fblan32            ,
        output wire         fblap32            ,
        output wire         fblan33            ,
        output wire         fblap33                 	
        );
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Signal definitions
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
wire          ninit_done/* synthesis keep */;
wire          S_global_resetn/* synthesis keep */;
reg  [26:0]   heart_beat_cnt/* synthesis keep */;
wire          clk_50m     ; // System clock, 50MHz
wire  [7:0]   fpga_led;
wire [31:0]   fmc_cmos_la_tx_parallel_data;
wire [31:0]   fmc_cmos_la_rx_parallel_data;
wire [31:0]   fmc_cmos_la_parallel_debug;
wire          fmc_cmos_la_loopback_en;
 sys_pll sys_pll_inst (
		.rst      (!S_global_resetn),      //   input,  width = 1,   reset.reset
		.refclk   (clk_gpio_p_4),   //   input,  width = 1,  refclk.clk
		.locked   ( ),   //  output,  width = 1,  locked.export
		.outclk_0 (clk_50m)  //  output,  width = 1, outclk0.clk
	);
	
//----------------------------------------------------------------------------------------------------------
// Intel Agilex Reset Release
//----------------------------------------------------------------------------------------------------------
reset_release reset_release_inst 
              (
              .ninit_done (ninit_done)  // ninit_done.ninit_done
              );
assign S_global_resetn = !ninit_done & fpga_resetn;
  sgpio_slave sgpio_slave_inst(
    .i_rstn     (S_global_resetn ),
    .i_clk      (fpga_sgpio_clk  ),
    .i_sync     (fpga_sgpio_sync ),
    .i_mosi     (fpga_sgpi       ),
    .o_miso     (fpga_sgpo       ),
    .o_user_sw  (         ),
    .i_user_led (fpga_led        )
  );
assign fpga_led = {5'hf,!heart_beat_cnt[25], ninit_done, heart_beat_cnt[26]};
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Heart-beat indicate
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
always @(posedge clk_50m or negedge S_global_resetn)
    if (!S_global_resetn)
        heart_beat_cnt <= 27'h0; //0x7FFFFFF
    else
        heart_beat_cnt <= heart_beat_cnt + 1'b1;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//CMOS interface
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
assign {
        fblap3,   
        fblan3,
        fblap6,
        fblan6,
        fblap8,
        fblan8,
        fblap10,
        fblan10,
        fblap12,
        fblan12,
        fblap14,
        fblan14,
        fblap16,
        fblan16,
        fblap18,
        fblan18,
        fblap20,
        fblan20,
        fblap22,
        fblan22,
        fblap25,
        fblan25,
        fblap27,
        fblan27,
        fblap29,
        fblan29,
        fblap31,
        fblan31,
        fblap33,
        fblan33,
        fblap32,
        fblan32  // bit32
        } = fmc_cmos_la_loopback_en ? fmc_cmos_la_parallel_debug : fmc_cmos_la_tx_parallel_data;   
assign	fmc_cmos_la_rx_parallel_data = fmc_cmos_la_loopback_en ? fmc_cmos_la_tx_parallel_data :	
                                                                    {
                                                                    fblap2,         
                                                                    fblan2,
                                                                    fblap4,
                                                                    fblan4,
                                                                    fblap5,
                                                                    fblan5,
                                                                    fblap7,
                                                                    fblan7,
                                                                    fblap9,
                                                                    fblan9,
                                                                    fblap11,
                                                                    fblan11,
                                                                    fblap13,
                                                                    fblan13,
                                                                    fblap15,
                                                                    fblan15,
                                                                    fblap17,
                                                                    fblan17,
                                                                    fblap19,
                                                                    fblan19,
                                                                    fblap21,
                                                                    fblan21,
                                                                    fblap23,
                                                                    fblan23,
                                                                    fblap24,
                                                                    fblan24,
                                                                    fblap26,
                                                                    fblan26,
                                                                    fblap28,
                                                                    fblan28,
                                                                    fblap30,
                                                                    fblan30        // bit32
                                                                   };
																   
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//XCVR system Qsys module
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
q_sys   q_sys_u0 (
        .clk_50_clk                                               (clk_50m       ), //  input,  width = 1,                                              clk.clk
        .reset_50_reset_n                                         (S_global_resetn        ),
		.clk_100_clk                                              (clk_gpio_p_4),
		.reset_100_reset_n                                        (S_global_resetn        ), //input,  width = 1,                                            reset.reset_n
        .systemclk_f_0_refclk_fgt_in_refclk_fgt_2                 (refclk_fgt12Ach2_p   ), //                     systemclk_f_0_refclk_fgt.in_refclk_fgt_0
        .fmc_cmos_test_0_nativephy_loopback_cont_0_rx_seriallpbken_rx_seriallpbken  (fmc_cmos_la_loopback_en),  //  output,   width = 1, fmc_cmos_test_0_nativephy_loopback_cont_0_rx_seriallpbken.rx_seriallpbken
		.fmc_cmos_test_0_pio_0_external_connection_export                           (fmc_cmos_la_parallel_debug),                           //  output,  width = 32,                 fmc_cmos_test_0_pio_0_external_connection.export
		.fmc_cmos_test_0_xcvr_st_converter_cmos_0_tx_parallel_data_tx_parallel_data (fmc_cmos_la_tx_parallel_data), //  output,  width = 32, fmc_cmos_test_0_xcvr_st_converter_cmos_0_tx_parallel_data.tx_parallel_data
		.fmc_cmos_test_0_xcvr_st_converter_cmos_0_rx_parallel_data_rx_parallel_data (fmc_cmos_la_rx_parallel_data), //   input,  width = 32, fmc_cmos_test_0_xcvr_st_converter_cmos_0_rx_parallel_data.rx_parallel_data
		.ftile_xcvr_test_0_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[0]      ), //     ftile_xcvr_test_0_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_0_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[0]      ), //   ftile_xcvr_test_0_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_0_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[0]      ), //     ftile_xcvr_test_0_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_0_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[0]      ), //   ftile_xcvr_test_0_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_1_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[1]      ), //     ftile_xcvr_test_1_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_1_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[1]      ), //   ftile_xcvr_test_1_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_1_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[1]      ), //     ftile_xcvr_test_1_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_1_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[1]      ), //   ftile_xcvr_test_1_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_2_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[2]      ), //     ftile_xcvr_test_2_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_2_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[2]      ), //   ftile_xcvr_test_2_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_2_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[2]      ), //     ftile_xcvr_test_2_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_2_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[2]      ), //   ftile_xcvr_test_2_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_3_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[3]      ), //     ftile_xcvr_test_3_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_3_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[3]      ), //   ftile_xcvr_test_3_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_3_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[3]      ), //     ftile_xcvr_test_3_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_3_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[3]      ),  //   ftile_xcvr_test_3_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_4_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[4]      ), //     ftile_xcvr_test_4_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_4_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[4]      ), //   ftile_xcvr_test_4_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_4_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[4]      ), //     ftile_xcvr_test_4_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_4_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[4]      ), //   ftile_xcvr_test_4_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_5_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[5]      ), //     ftile_xcvr_test_5_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_5_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[5]      ), //   ftile_xcvr_test_5_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_5_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[5]      ), //     ftile_xcvr_test_5_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_5_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[5]      ), //   ftile_xcvr_test_5_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_6_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[6]      ), //     ftile_xcvr_test_6_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_6_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[6]      ), //   ftile_xcvr_test_6_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_6_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[6]      ), //     ftile_xcvr_test_6_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_6_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[6]      ), //   ftile_xcvr_test_6_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_7_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[7]      ), //     ftile_xcvr_test_7_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_7_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[7]      ), //   ftile_xcvr_test_7_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_7_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[7]      ), //     ftile_xcvr_test_7_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_7_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[7]      ),  //   ftile_xcvr_test_7_directphy_f_0_rx_serial_data_n.rx_serial_data_n
		.ftile_xcvr_test_8_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[8]      ), //     ftile_xcvr_test_8_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_8_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[8]      ), //   ftile_xcvr_test_8_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_8_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[8]      ), //     ftile_xcvr_test_8_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_8_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[8]      ), //   ftile_xcvr_test_8_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_9_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[9]      ), //     ftile_xcvr_test_9_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_9_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[9]      ), //   ftile_xcvr_test_9_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_9_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[9]      ), //     ftile_xcvr_test_9_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_9_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[9]      ), //   ftile_xcvr_test_9_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_10_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[10]      ), //     ftile_xcvr_test_10_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_10_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[10]      ), //   ftile_xcvr_test_10_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_10_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[10]      ), //     ftile_xcvr_test_10_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_10_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[10]      ), //   ftile_xcvr_test_10_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_11_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[11]      ), //     ftile_xcvr_test_11_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_11_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[11]      ), //   ftile_xcvr_test_11_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_11_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[11]      ), //     ftile_xcvr_test_11_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_11_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[11]      ),  //   ftile_xcvr_test_11_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_12_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[12]      ), //     ftile_xcvr_test_12_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_12_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[12]      ), //   ftile_xcvr_test_12_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_12_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[12]      ), //     ftile_xcvr_test_12_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_12_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[12]      ), //   ftile_xcvr_test_12_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_13_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[13]      ), //     ftile_xcvr_test_13_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_13_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[13]      ), //   ftile_xcvr_test_13_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_13_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[13]      ), //     ftile_xcvr_test_13_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_13_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[13]      ), //   ftile_xcvr_test_13_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_14_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[14]      ), //     ftile_xcvr_test_14_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_14_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[14]      ), //   ftile_xcvr_test_14_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_14_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[14]      ), //     ftile_xcvr_test_14_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_14_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[14]      ), //   ftile_xcvr_test_14_directphy_f_0_rx_serial_data_n.rx_serial_data_n
        .ftile_xcvr_test_15_directphy_f_0_tx_serial_data_tx_serial_data      (fmc_tx_p[15]      ), //     ftile_xcvr_test_15_directphy_f_0_tx_serial_data.tx_serial_data
        .ftile_xcvr_test_15_directphy_f_0_tx_serial_data_n_tx_serial_data_n  (fmc_tx_n[15]      ), //   ftile_xcvr_test_15_directphy_f_0_tx_serial_data_n.tx_serial_data_n
        .ftile_xcvr_test_15_directphy_f_0_rx_serial_data_rx_serial_data      (fmc_rx_p[15]      ), //     ftile_xcvr_test_15_directphy_f_0_rx_serial_data.rx_serial_data
        .ftile_xcvr_test_15_directphy_f_0_rx_serial_data_n_rx_serial_data_n  (fmc_rx_n[15]      )  //   ftile_xcvr_test_15_directphy_f_0_rx_serial_data_n.rx_serial_data_n
    );
endmodule
