// (C) 2001-2024 Intel Corporation. All rights reserved.
// Your use of Intel Corporation's design tools, logic functions and other 
// software and tools, and its AMPP partner logic functions, and any output 
// files from any of the foregoing (including device programming or simulation 
// files), and any associated documentation or information are expressly subject 
// to the terms and conditions of the Intel Program License Subscription 
// Agreement, Intel FPGA IP License Agreement, or other applicable 
// license agreement, including, without limitation, that your use is for the 
// sole purpose of programming logic devices manufactured by Intel and sold by 
// Intel or its authorized distributors.  Please refer to the applicable 
// agreement for further details.


`timescale 1ns / 100ps
module  bts_xcvr (
        //Reset&Clock
        input  wire        fpga_resetn    , // Reset, low active
        input  wire        clk_gpio_p_4     , // System clock, 100MHz
        input  wire        refclk_fgt13Cch1_p    , // SDI reference clock 148.35MHz 
		output wire        vcxo_fs_1v2 ,
		input  wire        lmh1219_lock_n ,
		input  wire        lmh1218_lock ,
		
		//SGPIO for dipsw, leds
        input  wire        fpga_sgpio_sync,
        input  wire        fpga_sgpio_clk ,
        input  wire        fpga_sgpi      ,    
        output wire        fpga_sgpo      ,
        //SDI XCVR channels
        input  wire        sdi_rx_p          , // SDI RX P
        input  wire        sdi_rx_n          , // SDI RX N
        output wire        sdi_tx_p          , // SDI TX P
        output wire        sdi_tx_n            // SDI TX N
        );
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Signal definitions
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
wire          ninit_done/* synthesis keep */;
wire          S_global_resetn/* synthesis keep */;
reg  [26:0]   heart_beat_cnt/* synthesis keep */;
wire          clk_50m     ; // System clock, 50MHz
wire  [7:0]   fpga_led;
assign vcxo_fs_1v2 = 1'b0;
 sys_pll sys_pll_inst (
		.rst      (!S_global_resetn),      //   input,  width = 1,   reset.reset
		.refclk   (clk_gpio_p_4),   //   input,  width = 1,  refclk.clk
		.locked   ( ),   //  output,  width = 1,  locked.export
		.outclk_0 (clk_50m)  //  output,  width = 1, outclk0.clk
	);
	
//----------------------------------------------------------------------------------------------------------
// Intel Agilex Reset Release
//----------------------------------------------------------------------------------------------------------
reset_release reset_release_inst 
              (
              .ninit_done (ninit_done)  // ninit_done.ninit_done
              );
assign S_global_resetn = !ninit_done & fpga_resetn;
  sgpio_slave sgpio_slave_inst(
    .i_rstn     (S_global_resetn ),
    .i_clk      (fpga_sgpio_clk  ),
    .i_sync     (fpga_sgpio_sync ),
    .i_mosi     (fpga_sgpi       ),
    .o_miso     (fpga_sgpo       ),
    .o_user_sw  (         ),
    .i_user_led (fpga_led        )
  );
assign fpga_led = {3'd7, lmh1219_lock_n, !lmh1218_lock, !heart_beat_cnt[25], ninit_done, heart_beat_cnt[26]};
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Heart-beat indicate
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
always @(posedge clk_50m or negedge S_global_resetn)
    if (!S_global_resetn)
        heart_beat_cnt <= 27'h0; //0x7FFFFFF
    else
        heart_beat_cnt <= heart_beat_cnt + 1'b1;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//XCVR system Qsys module
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
q_sys   q_sys_u0 (
        .clk_100_clk                                                       (clk_gpio_p_4      ), //                                      clk_100.clk
        .reset_100_reset_n                                                 (S_global_resetn   ), //                                    reset_100.reset_n
        .clk_50_clk                                                        (clk_50m           ), //                                       clk_50.clk
        .reset_50_reset_n                                                  (S_global_resetn   ), //                                     reset_50.reset_n
        .systemclk_f_0_refclk_fgt_in_refclk_fgt_1                          (refclk_fgt13Cch1_p), //                     systemclk_f_0_refclk_fgt.in_refclk_fgt_0
        .ftile_xcvr_test_0_directphy_f_0_tx_serial_data_tx_serial_data     (sdi_tx_p      ),   
        .ftile_xcvr_test_0_directphy_f_0_tx_serial_data_n_tx_serial_data_n (sdi_tx_n      ),  
        .ftile_xcvr_test_0_directphy_f_0_rx_serial_data_rx_serial_data     (sdi_rx_p      ),  
        .ftile_xcvr_test_0_directphy_f_0_rx_serial_data_n_rx_serial_data_n (sdi_rx_n      )        
		);
endmodule
