// (C) 2001-2024 Intel Corporation. All rights reserved.
// Your use of Intel Corporation's design tools, logic functions and other 
// software and tools, and its AMPP partner logic functions, and any output 
// files from any of the foregoing (including device programming or simulation 
// files), and any associated documentation or information are expressly subject 
// to the terms and conditions of the Intel Program License Subscription 
// Agreement, Intel FPGA IP License Agreement, or other applicable 
// license agreement, including, without limitation, that your use is for the 
// sole purpose of programming logic devices manufactured by Intel and sold by 
// Intel or its authorized distributors.  Please refer to the applicable 
// agreement for further details.

/*
Define macro(by delete //) to enable the corresponding interface, 
Undefine all HPS/XCVR interface by default
After opening the macro,corresponding Pin must be connected to IP, or else it will report fitter error because of missing IP.
*/

/*
Important Notice: Only support to enable one interface at one project
*/

//`define HPS_INTERFACE_ENABLE
//`define PCIE_INTERFACE_ENABLE
//`define FMCA_INTERFACE_ENABLE
//`define FMCB_INTERFACE_ENABLE
//`define QSFPDD0_1_INTERFACE_ENABLE
//`define QSFPDD800_INTERFACE_ENABLE
//`define MXPM_INTERFACE_ENABLE 
//`define SDI_INTERFACE_ENABLE 
//`define DP_INTERFACE_ENABLE

`timescale 1ns / 100ps
module  golden_top (
  //Reset&Clock
  input  wire       clk_gpio_p_4          , // system clock, 100M
  input  wire       fpga_resetn           , //sysmax_pb[1] to trigger hard reset
										   
  //I2C interfaces                         
  inout  wire       zl_i2c_scl_1v2        , //CH1, Access ZL30733, ZL_I2C_EN
  inout  wire       zl_i2c_sda_1v2        , 
  inout  wire       sdi_scl_1v2           , //CH2, Access LMH1218/LMH12189, CLK_I2C_EN0								
  inout  wire       sdi_sda_1v2		      , 
  inout  wire       i2c_qsfpdd0_scl       , //CH3, Access QSFPDD0, ZL_I2C_EN								
  inout  wire       i2c_qsfpdd0_sda	      , 
  inout  wire       i2c_qsfpdd1_scl       , //CH4, Access	QSFPDD1							
  inout  wire       i2c_qsfpdd1_sda	      ,
  inout  wire       i2c_qsfpdd800_scl     , //CH5, Access	QSFPDD800							
  inout  wire       i2c_qsfpdd800_sda	  ,	
  inout  wire       ddr4_dimm_2_scl_1v2   , //CH6, Access	DIMM-A/DIMM-B							
  inout  wire       ddr4_dimm_2_sda_1v2   ,
  inout  wire       vcxo_scl_1v2          , //CH7, Access	VCXO							
  inout  wire       vcxo_sda_1v2		  ,
  inout  wire       clk_i2c_scl_1v2	      , //CH8, Access	CLOCK BUFFER			
  inout  wire       clk_i2c_sda_1v2	      ,  
  inout  wire       i2c_fmca_scl		  , //CH9, Access	FMC-A			
  inout  wire       i2c_fmca_sda		  ,
  inout  wire       i2c_fmcb_scl		  , //CH10, Access  FMC-B			
  inout  wire       i2c_fmcb_sda		  ,
										   
  //GPIO                                   
  input  wire       f_gpio0               , //user_pb0
  input  wire       f_gpio1               , //user_pb1
  output wire       f_gpio2               , //MCIO_PERST in RP Mode
  output wire       f_gpio3               , //FMC_A PERST in RP Mode
  output wire       f_gpio4               , //FMC_B PERST in RP Mode 
  inout  wire       f_gpio5         	   , 
  inout  wire       f_gpio6         	   , 
  inout  wire       f_gpio7         	   , 
  inout  wire       f_gpio8         	   , 
  inout  wire       f_gpio9         	   , 
  inout  wire       f_gpio10         	   , 
  inout  wire       f_gpio11         	   , 
  inout  wire       f_gpio12         	   , 
										   
  //SGPIO for dipsw, leds                  
  input  wire       fpga_sgpio_sync       ,
  input  wire       fpga_sgpio_clk        ,
  input  wire       fpga_sgpi             ,    
  output wire       fpga_sgpo             , 
										   
 //inc_dec_pulse                           
  output wire       inc_pulse             ,
  output wire       dec_pulse             ,
										   
 //optical module signal                   
  output wire       qsfpdd0_lpmode        , // QSFPDD0 GPIOs
  output wire       qsfpdd0_modsell       , // QSFPDD0 GPIOs
  output wire       qsfpdd0_resetl        , // QSFPDD0 GPIOs
  output wire       qsfpdd0_epps          , // QSFPDD0 GPIOs
  input  wire       qsfpdd0_modprsl       , // QSFPDD0 GPIOs
  input  wire       qsfpdd0_intl          , // QSFPDD0 GPIOs

  output wire       qsfpdd1_lpmode        , // QSFPDD1 GPIOs
  output wire       qsfpdd1_modsell       , // QSFPDD1 GPIOs
  output wire       qsfpdd1_resetl        , // QSFPDD1 GPIOs
  output wire       qsfpdd1_epps          , // QSFPDD0 GPIOs
  input  wire       qsfpdd1_modprsl       , // QSFPDD1 GPIOs
  input  wire       qsfpdd1_intl          , // QSFPDD1 GPIOs

  output wire       qsfpdd800_lpmode     , // QSFPDD800 GPIOs
  output wire       qsfpdd800_modsell    , // QSFPDD800 GPIOs
  output wire       qsfpdd800_resetl     , // QSFPDD800 GPIOs
  output wire       qsfpdd800_epps        , // QSFPDD0 GPIOs
  input  wire       qsfpdd800_modprsl    , // QSFPDD800 GPIOs
  input  wire       qsfpdd800_intl       , // QSFPDD800 GPIOs
  
  //USB2.0
  inout  wire       usb_d0_1v2            ,
  inout  wire       usb_d1_1v2            ,
  inout  wire       usb_d2_1v2            ,
  inout  wire       usb_d3_1v2            ,
  inout  wire       usb_d4_1v2            ,
  inout  wire       usb_d5_1v2            ,
  inout  wire       usb_d6_1v2            ,
  inout  wire       usb_d7_1v2            ,
  input  wire       usb_clk_1v2           ,
  input  wire       usb_nxt_1v2           ,
  input  wire       usb_dir_1v2           ,
  output wire       usb_stp_1v2           ,
  input  wire       vbus_det_1v2          ,
  
  //1PPS/ToD
  input  wire       b_1pps_fpga_clk       ,
  output wire       b_sel_1pps_inout      ,
  output wire       fpga_1pps_out         ,
  output wire       b_shdn_1pps_to_10mhz  ,
  output wire       b_shdn_10mhz_out      ,
  output wire       b_shdn_10mhz_in       ,
  input  wire       tod_clk_100m_p        ,

  //ZL30733 SPI
  output wire       zl_spi_sck_1v2        ,
  output wire       zl_spi_si_1v2         ,
  output wire       zl_spi_cs_1v2         , 
  input  wire       zl_spi_so_1v2         ,  
  
  //other control signals
  input  wire       ddr4_dimm_2_eventn_1v2,
  output wire       ddr4_dimm_2_saven_1v2 ,
  input  wire       lmh1219_lockn_1v2     ,
  input  wire       lmh1218_lockn_1v2     ,
  input  wire       b_ptp_clk_lol         ,
  input  wire       lmh1218_los_intn_1v2  ,
  input  wire       b_fpga_hps_zl_ho      ,
  output wire       vcxo_fs_1v2           ,
  
  //GPIO clock
  input  wire       clk_3c_gpio_p_1       ,
  input  wire       clk_3c_gpio_p_0       ,
  input  wire       clk_3a_gpio_p_2       ,
  input  wire       clk_3a_gpio_p_1       ,
  input  wire       clk_3a_gpio_p_0       ,
  
  //sidebus
  inout              usb_scl               ,
  inout              usb_sda               ,
  input              usb_resetn            ,   
  input              usb_fpga_clk          ,
  output [1:0]       usb_addr              , 
  inout  [7:0]       usb_data              ,  
  input              usb_wrn               ,
  input              usb_rdn               ,
  input              usb_oen               ,
  output             usb_full              ,
  output             usb_empty             , 
   
  //Dual RDIMM                             
  input  wire        ddr4_dimm_2_refclkp   , // ddr_ref_clk.clk
  output wire [1:0]  ddr4_dimm_2_ckp       , // mem_ck
  output wire [1:0]  ddr4_dimm_2_ckn       , // mem_ck_n
  output wire [16:0] ddr4_dimm_2_a         , // mem_a
  output wire        ddr4_dimm_2_actn      , // mem_act_n
  output wire [1:0]  ddr4_dimm_2_ba        , // mem_ba
  output wire [1:0]  ddr4_dimm_2_bg        , // mem_bg		            
  output wire [1:0]  ddr4_dimm_2_cke       , // mem_cke
  output wire [1:0]  ddr4_dimm_2_csn       , // mem_cs_n
  output wire [1:0]  ddr4_dimm_2_odt       , // mem_odt
  output wire        ddr4_dimm_2_rstn      , // mem_reset_n
  output wire        ddr4_dimm_2_par       , // mem_par
  input  wire        ddr4_dimm_2_alertn    , // mem_alert_n
  inout  wire [17:0] ddr4_dimm_2_dqsp      , // mem_dqs
  inout  wire [17:0] ddr4_dimm_2_dqsn      , // mem_dqs_n
  inout  wire [71:0] ddr4_dimm_2_dq        , // mem_dq               
  input  wire        ddr4_dimm_2_rzq        // oct_rzqin
  

`ifdef HPS_INTERFACE_ENABLE
  //HPS                                
  , input  wire        ddr4_hps_refclkp      , // ddr_ref_clk.clk
  output wire        ddr4_hps_ckp          , // mem_ck
  output wire        ddr4_hps_ckn          , // mem_ck_n
  output wire [16:0] ddr4_hps_a            , // mem_a
  output wire        ddr4_hps_actn         , // mem_act_n
  output wire [1:0]  ddr4_hps_ba           , // mem_ba
  output wire        ddr4_hps_bg0          , // mem_bg
  output wire        ddr4_hps_cke          , // mem_cke
  output wire        ddr4_hps_csn          , // mem_cs_n
  output wire        ddr4_hps_odt          , // mem_odt
  output wire        ddr4_hps_rstn         , // mem_reset_n
  output wire        ddr4_hps_par          , // mem_par
  input  wire        ddr4_hps_alertn       , // mem_alert_n
  inout  wire [8:0]  ddr4_hps_dqsp         , // mem_dqs
  inout  wire [8:0]  ddr4_hps_dqsn         , // mem_dqs_n
  inout  wire [71:0] ddr4_hps_dq           , // mem_dq
  inout  wire [8:0]  ddr4_hps_dbi          , // mem_dbi_n
  input  wire        ddr4_hps_rzq          , // oct_rzqin
  
  inout  wire [47:0] hps_gpio              
`endif
 
/*
  //List All XCVR clock, the user should to choose the correct XCVR clock
  input wire         clk_a_12c_fgt_p_0     , // Reference clock #Bank12C_FGT_CH0 from U22 (Si53307) output #0
  input wire         clk_a_12c_fgt_p_1     , // Reference clock #Bank12C_FGT_CH1 from U108 (Si53307) output #0
  input wire         clk_a_12c_fgt_p_2     , // Reference clock #Bank12C_FGT_CH2 from U23 (Si53307) output #0
  input wire         clk_a_12c_fgt_p_3     , // Reference clock #Bank12C_FGT_CH3 from U24 (Si53307) output #0
  input wire         clk_a_12c_fgt_p_4     , // Reference clock #Bank12C_FGT_CH4 from U26 (Si53307) output #0
  input wire         clk_a_12c_fgt_p_5     , // Reference clock #Bank12C_FGT_CH5 from U27 (Si53307) output #0
  input wire         clk_a_12c_fgt_p_6     , // Reference clock #Bank12C_FGT_CH6 from U109 (Si53307) output #0
  input wire         clk_a_12c_fgt_p_7     , // Reference clock #Bank12C_FGT_CH7 from U25 (Si53307) output #0
  output wire        rcvd_clko_12c_ch8_p1  , // Reference clock #Bank12C_FGT_CH8 to U20 (Si53307) input #0
  input wire         rcvd_clko_12c_ch9_p1  , // Reference clock #Bank12C_FGT_CH9 from SMA header J12/J13
			         
  input wire         clk_b_12a_fgt_p_0     , // Reference clock #Bank12A_FGT_CH0 from U46 (Si53307) output #0
  input wire         clk_b_12a_fgt_p_1     , // Reference clock #Bank12A_FGT_CH1 from U108 (Si53307) output #1
  input wire         clk_b_12a_fgt_p_2     , // Reference clock #Bank12A_FGT_CH2 from U53 (Si53307) output #0
  input wire         clk_b_12a_fgt_p_3     , // Reference clock #Bank12A_FGT_CH3 from U56 (Si53307) output #0
  input wire         clk_b_12a_fgt_p_4     , // Reference clock #Bank12A_FGT_CH4 from U57 (Si53307) output #0
  input wire         clk_b_12a_fgt_p_5     , // Reference clock #Bank12A_FGT_CH5 from U61 (Si53307) output #0
  input wire         clk_b_12a_fgt_p_6     , // Reference clock #Bank12A_FGT_CH6 from U60 (Si53307) output #0
  input wire         clk_b_12a_fgt_p_7     , // Reference clock #Bank12A_FGT_CH7 from U25 (Si53307) output #1
  output wire        rcvd_clko_12a_ch8_p1  , // Reference clock #Bank12A_FGT_CH8 to U20 (Si53307) input #1
  input wire         rcvd_clko_12a_ch9_p1  , // Reference clock #Bank12A_FGT_CH9 from SMA header J15/J16
			         
  input wire         clk_fht_13a_p_0       , // Reference clock #Bank13A_FHT_CH0 from U118 (Si5394) output #0
  input wire         clk_fht_13a_p_1       , // Reference clock #Bank13A_FHT_CH1 from SMA header J38/J45  
  input wire         clk_13a_fgt_refclk0_p , // Reference clock #Bank13A_FGT_CH0 from U48 (Si53307) output #0
  input wire         clk_13a_fgt_refclk2_p , // Reference clock #Bank13A_FGT_CH2 from U45 (Si5391A) output #4    
  input wire         clk_13a_fgt_refclk3_p , // Reference clock #Bank13A_FGT_CH3 from U45 (Si5391A) output #9A
  input wire         clk_13a_fgt_refclk4_p , // Reference clock #Bank13A_FGT_CH4 from U45 (Si5391A) output #1
			         
  input wire         clk_fht_13c_p_0       , // Reference clock #Bank13A_FHT_CH0 from U118 (Si5394) output #1
  input wire         clk_fht_13c_p_1       , // Reference clock #Bank13A_FHT_CH1 from SMA header J23/J24    
  input wire         si5332_out7_p         , // Reference clock #Bank13C_FGT_CH0 from U19 (Si5332E) output #7
  input wire         clk_vcxo_mux_2p       , // Reference clock #Bank13C_FGT_CH1 from U54 (Si566) output    
  input wire         clk_fgt_13c_refclk_2p , // Reference clock #Bank13C_FGT_CH2 from U118 (Si5394) output #3
  input wire         clk_13c_fgt_p3        , // Reference clock #Bank13C_FGT_CH3 from SMA header J25/J26
  input wire         eth_refclk_156m25_p  , // Reference clock #Bank13C_FGT_CH4 from U123B (ZL30733) output #3
  input wire         cpri_refclk_153m6_p  , // Reference clock #Bank13C_FGT_CH5 from U123B (ZL30733) output #4    
  input wire         zl_spare_clk_100m     , // Reference clock #Bank13C_FGT_CH6 from U123B (ZL30733) output #2  
  input wire         cpri_refclk_184m32_p , // Reference clock #Bank13C_FGT_CH7 from U123B (ZL30733) output #5 
  output wire        qsfp_rcvd_clk1_p      , // Reference clock #Bank13C_FGT_CH8 from U123C (ZL30733) input #0
  output wire        qsfp_rcvd_clk2_p      , // Reference clock #Bank13C_FGT_CH9 from U123C (ZL30733) input #1 
 */ 
 
  //PCIe Gen4.0
`ifdef PCIE_INTERFACE_ENABLE
  , input  wire       pin_perst_pin_perst  , // pin_perst.pin_perst
  input  wire [3:0]   pcie_rx_p            , // hip_serial_rx_n_in
  input  wire [3:0]   pcie_rx_n            , // hip_serial_rx_p_in
  output wire [3:0]   pcie_tx_p            , // hip_serial_tx_n_out
  output wire [3:0]   pcie_tx_n            , // hip_serial_tx_p_out
  input wire          clk_13a_fgt_refclk0_p  // Reference clock #Bank13A_FGT_CH0 from U48 (Si53307) output #0

`endif
										   
  //FMCA 
`ifdef FMCA_INTERFACE_ENABLE  
  , input  wire [15:0]  fmca_rx_p            , // FMC_A RX P
  input  wire [15:0]  fmca_rx_n            , // FMC_A RX N
  output wire [15:0]  fmca_tx_p            , // FMC_A TX P
  output wire [15:0]  fmca_tx_n            , // FMC_A TX N
  input wire          clk_a_12c_fgt_p_2    , // Reference clock #Bank12C_FGT_CH2 from U23 (Si53307) output #0
  
  input  wire         falan0               , // input,  lvds/cmos loopback test is not supported, input clock from loopback card
  input  wire         falap0               , // input,  lvds/cmos loopback test is not supported, input clock from loopback card
  output wire         falan1               , // output, lvds/cmos loopback test is not supported, output clock to loopback card
  output wire         falap1               , // output, lvds/cmos loopback test is not supported, output clock to loopback card       
  input  wire         falan2               ,
  input  wire         falap2               ,
  output wire         falan3               ,
  output wire         falap3               ,
  input  wire         falan4               ,
  input  wire         falap4               ,
  input  wire         falan5               ,
  input  wire         falap5               ,
  output wire         falan6               ,
  output wire         falap6               ,
  input  wire         falan7               ,
  input  wire         falap7               ,
  output wire         falan8               ,
  output wire         falap8               ,
  input  wire         falan9               ,
  input  wire         falap9               ,
  output wire         falan10              ,
  output wire         falap10              ,
  input  wire         falan11              ,
  input  wire         falap11              ,
  output wire         falan12              ,
  output wire         falap12              ,
  input  wire         falan13              ,
  input  wire         falap13              ,
  output wire         falan14              ,
  output wire         falap14              ,
  input  wire         falan15              ,
  input  wire         falap15              ,
  output wire         falan16              ,
  output wire         falap16              ,
  input  wire         falan17              ,
  input  wire         falap17              ,
  output wire         falan18              ,
  output wire         falap18              ,
  input  wire         falan19              ,
  input  wire         falap19              ,
  output wire         falan20              ,
  output wire         falap20              ,
  input  wire         falan21              ,
  input  wire         falap21              ,
  output wire         falan22              ,
  output wire         falap22              ,
  input  wire         falan23              ,
  input  wire         falap23              ,
  input  wire         falan24              ,
  input  wire         falap24              ,
  output wire         falan25              ,
  output wire         falap25              ,
  input  wire         falan26              ,
  input  wire         falap26              ,
  output wire         falan27              ,
  output wire         falap27              ,
  input  wire         falan28              ,
  input  wire         falap28              ,
  output wire         falan29              ,
  output wire         falap29              ,
  input  wire         falan30              ,
  input  wire         falap30              ,
  output wire         falan31              ,
  output wire         falap31              ,
  output wire         falan32              ,
  output wire         falap32              ,
  output wire         falan33              ,
  output wire         falap33                      
`endif
 
  //FMCB  
`ifdef FMCB_INTERFACE_ENABLE   
  , input  wire [15:0]  fmcb_rx_p            , // FMC_B RX P    
  input  wire [15:0]  fmcb_rx_n            , // FMC_B RX N
  output wire [15:0]  fmcb_tx_p            , // FMC_B TX P
  output wire [15:0]  fmcb_tx_n            , // FMC_B TX N
  input wire          clk_b_12a_fgt_p_2    , // Reference clock #Bank12A_FGT_CH2 from U53 (Si53307) output #0
  
  input  wire         fblan0               , // input,  lvds/cmos loopback test is not supported, input clock from loopback card
  input  wire         fblap0               , // input,  lvds/cmos loopback test is not supported, input clock from loopback card
  output wire         fblan1               , // output, lvds/cmos loopback test is not supported, output clock to loopback card
  output wire         fblap1               , // output, lvds/cmos loopback test is not supported, output clock to loopback card       
  input  wire         fblan2               ,
  input  wire         fblap2               ,
  output wire         fblan3               ,
  output wire         fblap3               ,
  input  wire         fblan4               ,
  input  wire         fblap4               ,
  input  wire         fblan5               ,
  input  wire         fblap5               ,
  output wire         fblan6               ,
  output wire         fblap6               ,
  input  wire         fblan7               ,
  input  wire         fblap7               ,
  output wire         fblan8               ,
  output wire         fblap8               ,
  input  wire         fblan9               ,
  input  wire         fblap9               ,
  output wire         fblan10              ,
  output wire         fblap10              ,
  input  wire         fblan11              ,
  input  wire         fblap11              ,
  output wire         fblan12              ,
  output wire         fblap12              ,
  input  wire         fblan13              ,
  input  wire         fblap13              ,
  output wire         fblan14              ,
  output wire         fblap14              ,
  input  wire         fblan15              ,
  input  wire         fblap15              ,
  output wire         fblan16              ,
  output wire         fblap16              ,
  input  wire         fblan17              ,
  input  wire         fblap17              ,
  output wire         fblan18              ,
  output wire         fblap18              ,
  input  wire         fblan19              ,
  input  wire         fblap19              ,
  output wire         fblan20              ,
  output wire         fblap20              ,
  input  wire         fblan21              ,
  input  wire         fblap21              ,
  output wire         fblan22              ,
  output wire         fblap22              ,
  input  wire         fblan23              ,
  input  wire         fblap23              ,
  input  wire         fblan24              ,
  input  wire         fblap24              ,
  output wire         fblan25              ,
  output wire         fblap25              ,
  input  wire         fblan26              ,
  input  wire         fblap26              ,
  output wire         fblan27              ,
  output wire         fblap27              ,
  input  wire         fblan28              ,
  input  wire         fblap28              ,
  output wire         fblan29              ,
  output wire         fblap29              ,
  input  wire         fblan30              ,
  input  wire         fblap30              ,
  output wire         fblan31              ,
  output wire         fblap31              ,
  output wire         fblan32              ,
  output wire         fblap32              ,
  output wire         fblan33              ,
  output wire         fblap33             
`endif
   
  //QSFPDD0&1  
`ifdef QSFPDD0_1_INTERFACE_ENABLE 
  //QSFPDD0 
  , input  wire [7:0]   qsfpdd0_rx_p         , // QSFPDD #0 RX P
  input  wire [7:0]   qsfpdd0_rx_n         , // QSFPDD #0 RX N
  output wire [7:0]   qsfpdd0_tx_p         , // QSFPDD #0 TX P
  output wire [7:0]   qsfpdd0_tx_n         , // QSFPDD #0 TX N
  input wire          eth_refclk_156m25_p  , // Reference clock #Bank13C_FGT_CH4 from U123B (ZL30733) output #3  

  //QSFPDD1  
  input  wire [7:0]   qsfpdd1_rx_p         , // QSFPDD #1 RX P
  input  wire [7:0]   qsfpdd1_rx_n         , // QSFPDD #1 RX N
  output wire [7:0]   qsfpdd1_tx_p         , // QSFPDD #1 TX P
  output wire [7:0]   qsfpdd1_tx_n         , // QSFPDD #1 TX N
  input wire          clk_13a_fgt_refclk4_p  // Reference clock #Bank13A_FGT_CH4 from U45 (Si5391A) output #1
`endif  
  
  //QSDPDD800  
`ifdef QSFPDD800_INTERFACE_ENABLE  
  , input  wire [7:0]   qsfpdd800_rx_p       , // QSFPDD800 RX P
  input  wire [7:0]   qsfpdd800_rx_n       , // QSFPDD800 RX N
  output wire [7:0]   qsfpdd800_tx_p       , // QSFPDD800 TX P
  output wire [7:0]   qsfpdd800_tx_n       , // QSFPDD800 TX N
  
  input wire          clk_13a_fgt_refclk4_p, // Reference clock #Bank13A_FGT_CH4 from U45 (Si5391A) output #1
  input wire          clk_fht_13a_p_0      , // Reference clock #Bank13A_FHT_CH0 from U118 (Si5394) output #0
  input wire          eth_refclk_156m25_p  , // Reference clock #Bank13C_FGT_CH4 from U123B (ZL30733) output #3
  input wire          clk_fht_13c_p_0        // Reference clock #Bank13A_FHT_CH0 from U118 (Si5394) output #1
  
`endif  

  //FGT MXPM  
`ifdef MXPM_INTERFACE_ENABLE
  , input  wire [3:0]   mxpm_rx_p        , // MXPM RX P
  input  wire [3:0]   mxpm_rx_n        , // MXPM RX N
  output wire [3:0]   mxpm_tx_p        , // MXPM TX P
  output wire [3:0]   mxpm_tx_n        , // MXPM TX N
  input wire          clk_13a_fgt_refclk4_p  //Reference clock #Bank13A_FGT_CH4 from U45 (Si5391A) output #1
                                             //Default to use the same clock with the MXPM example design                                              
`endif

  //SDI  
`ifdef SDI_INTERFACE_ENABLE 
  , input  wire         sdi_rx_p             , // SDI RX P
  input  wire         sdi_rx_n             , // SDI RX N
  output wire         sdi_tx_p             , // SDI TX P
  output wire         sdi_tx_n             , // SDI TX N
  input wire          clk_vcxo_mux_2p        // Reference clock #Bank13C_FGT_CH1 from U54 (Si566) output    
                                             //Default to use the SDI clock with the MXPM example design
`endif
 
  //DP
`ifdef DP_INTERFACE_ENABLE   
  , input  wire         fgt_13c_rx0_dp       , // DP RX P
  input  wire         fgt_13c_rx0_dn       , // DP RX N
  output wire         fgt_13c_tx0_dp       , // DP TX P  
  output wire         fgt_13c_tx0_dn       , // DP TX N 
  input wire          si5332_out7_p          // Reference clock #Bank13C_FGT_CH0 from U19 (Si5332E) output #7
                                             
`endif
 
  );



 endmodule
 