
#debug
set run_step 0

proc debug {} {
	global run_step
	incr run_step
	puts $run_step
}

#debug


#***************************
#global setting

set i2c_master_addr 	  0x500
set INPUT_CLOCK  			50000000
set ALT_AVALON_I2C_DIFF_LCNT_HCNT 60
#register addr
set TFR_CMD 				[format 0x%x [expr $i2c_master_addr + [expr 0 * 4]]]
set RX_DATA 				[format 0x%x [expr $i2c_master_addr + [expr 1 * 4]]]
set CTRL 					[format 0x%x [expr $i2c_master_addr + [expr 2 * 4]]]
set ISER 					[format 0x%x [expr $i2c_master_addr + [expr 3 * 4]]]
set ISR 					[format 0x%x [expr $i2c_master_addr + [expr 4 * 4]]]
set STATUS 					[format 0x%x [expr $i2c_master_addr + [expr 5 * 4]]]
set TFR_CMD_FIFO_LVL 		[format 0x%x [expr $i2c_master_addr + [expr 6 * 4]]]
set RX_DATA_FIFO_LVL 		[format 0x%x [expr $i2c_master_addr + [expr 7 * 4]]]
set SCL_LOW 				[format 0x%x [expr $i2c_master_addr + [expr 8 * 4]]]
set SCL_HIGH 				[format 0x%x [expr $i2c_master_addr + [expr 9 * 4]]]
set SDA_HOLD 				[format 0x%x [expr $i2c_master_addr + [expr 10 * 4]]]


#***************************
# target master service path
proc master_service_path_target { board_usb_port_no board_device_no } {
	 set service_path_no {};
     #set MATCHER "/devices/VTAP*@*#USB-*phy*"
     set MATCHER "/devices/10M50*"
     #print master service paths array
     set jtag_master_array [get_service_paths master]\n
     format $jtag_master_array
     set jtag_master_array_length [llength $jtag_master_array]
     
     for {set i 0} {$i < $jtag_master_array_length} {incr i 1} {
          puts "jtag master #$i: [lindex $jtag_master_array $i]\n"
          if {[string match $MATCHER [lindex $jtag_master_array $i]]} {
              set service_path_no $i
          } 
     }

     if {$service_path_no == ""} {
         error "No USB connection found"
     }

     #choose specific master service path
     set service_path [lindex $jtag_master_array $service_path_no]; # To choose correct master service path during test
	 return $service_path
}

#***********************************************************************
# master_write_x32
proc master_write_x32 { master_addr data_write_array} {
	 global service_path
     format $data_write_array
     set data_write_length [llength $data_write_array]
     for {set i 0} {$i < $data_write_length} {incr i 1} {
         master_write_32 $service_path [format 0x%x [expr $master_addr + [expr $i * 4]]] [lindex $data_write_array $i]
         #puts "Current write address: [format 0x%x [expr $master_addr + [expr $i * 4]]]\n"
         }
		
}

#***********************************************************************
# master_read_x32
proc master_read_x32 { master_addr data_read_length } {
	 global service_path
     set master_read_array [master_read_32 $service_path $master_addr $data_read_length]
	 format $master_read_array
	 set data [lindex $master_read_array 0]
	 return $data
}

#******low level function***********
proc clearISR { } {
	global ISR
	master_write_x32 $ISR 0x1F
}
proc IOWR_TFRCMD { data } {
	global TFR_CMD
	master_write_x32 $TFR_CMD $data
}
proc IORD_RX_DATA { } {
	global RX_DATA
	return [master_read_x32 $RX_DATA 1]
}
proc IOWR_CTRL { data } {
	global CTRL
	master_write_x32 $CTRL $data
}
proc IORD_CTRL { } {
	global CTRL
	return [master_read_x32 $CTRL 1]
}
proc IOWR_ISER { data } { 
	global ISER
	master_write_x32 $ISER $data
}
proc IORD_ISER { } {
	global ISER
	return [master_read_x32 $ISER 1]
}
proc IOWR_ISR { data } {
	global ISR
	master_write_x32 $ISR $data
}
proc IORD_ISR { } {
	global ISR
	return [master_read_x32 $ISR 1]
}
proc IORD_TFR_CMD_FIFOLVL { } {
	global TFR_CMD_FIFO_LVL
	return [master_read_x32 $TFR_CMD_FIFO_LVL 1]
}
proc IORD_RXDATA_FIFOLVL { } {
	global RX_DATA_FIFO_LVL
	return [master_read_x32 $RX_DATA_FIFO_LVL 1]
}
proc IOWR_SCL_LOW { data } {
	global SCL_LOW
	master_write_x32 $SCL_LOW $data 
}
proc IORD_SCL_LOW {} {
	global SCL_LOW
	return [master_read_x32 $SCL_LOW 1]
}
proc IOWR_SCL_HIGH { data } {
	global SCL_HIGH
	master_write_x32 $SCL_HIGH $data
}
proc IORD_SCL_HIGH { } {
	global SCL_HIGH
	return [master_read_x32 $SCL_HIGH 1]
}
proc IORD_SDA_HOLD { } {
	global SDA_HOLD
	return [master_read_x32 $SDA_HOLD 1]
}
proc IOWR_SDA_HOLD { data } { 
	global SDA_HOLD
	master_write_x32 $SDA_HOLD $data
}
proc IORD_STATUS { } {
	global STATUS
	set data [master_read_x32 $STATUS 1]
	return [expr $data & 1] 
}


#*********up low functions ******************

#check tx ready
proc i2c_check_txReady { } {
	set data [expr [IORD_ISR] & 1] 	
	for {set i 0} {$i < 100} {incr i 1} {
		if { $data == 0 } {
			after 1
			set data [expr [IORD_ISR] & 1]
			if {$i == 99 } {
			puts "TX READY TIME OUT!"
			}
		} else {
			break
		}							
	}
}


#initialize Avalon i2c core
proc i2c_init {} {
	global ALT_AVALON_I2C_DIFF_LCNT_HCNT
	global INPUT_CLOCK
	#turn off core
	IOWR_CTRL 0
	
	#set i2c clock
	set tick [expr $INPUT_CLOCK / 100000 / 2 ]
	set low_cnt [expr $tick - $ALT_AVALON_I2C_DIFF_LCNT_HCNT]
	set high_cnt [expr $tick + $ALT_AVALON_I2C_DIFF_LCNT_HCNT]
	IOWR_SCL_LOW $low_cnt
	IOWR_SCL_HIGH $high_cnt
	IOWR_SDA_HOLD [expr $low_cnt - $low_cnt/2]

	#enable core
	set value [expr 0x0C | 0x30 | 1]
	IOWR_CTRL $value

}

#close core
proc i2c_close {} {
	set data [IORD_CTRL]
	IOWR_CTRL [expr $data & 0xFE]
}

#i2c start
proc i2c_start {slave_addr isRead isRestart  } {
#	global slave_addr	
	clearISR
	i2c_check_txReady

	set data [expr $slave_addr << 1]
	if { $isRead == 1 }  {
	
		set data [expr $data | 1]
	}
	if {$isRestart == 1} {
		set data [expr $data | 0x200]
	}
	IOWR_TFRCMD $data
	i2c_check_txReady	
	set ISR_data [IORD_ISR]
	set ack_bit [expr $ISR_data & 4]
	#if {$ack_bit != 0 } {
	#	puts "i2c_start NO ACK!"
	#}
	return $ack_bit
}

proc i2c_scan {slave_addr isRead isRestart isstop  } {
	i2c_init
	set ack_bit [i2c_start $slave_addr $isRead $isRestart ]
	set ack_bit_1 [i2c_write 0 $isstop]
	i2c_close
	set ack_bit [expr $ack_bit|$ack_bit_1]
	return $ack_bit
}


#i2c read
proc i2c_read { } { 
	
	for {set i 0} {$i < 100} {incr i 1} {
		if { [IORD_RXDATA_FIFOLVL] == 0 } {
			after 1		
			if { $i == 99 } {
				puts "I2C READ TIME OUT"
			}
		} else {
			break
		}	
	}
	return [IORD_RX_DATA]
}

#i2c write
proc i2c_write { data stop} {

	i2c_check_txReady
	if { $stop } {
		IOWR_TFRCMD [expr $data | 0x100]
	} else {
		IOWR_TFRCMD $data
	}	
	i2c_check_txReady
	set data [IORD_ISR]
	set data [expr  $data & 4]
	#if {$data != 0 } {
	#	puts "i2c_write NO ACK!"
	#}
}

#read reg(8bit)
proc i2c_read_reg8 {slave_addr reg  } {
	i2c_init
	i2c_start $slave_addr 0 0 
	i2c_write $reg 0
	i2c_start $slave_addr 1 1
	i2c_write 0 1
	set data [i2c_read]
	i2c_close
	return $data
}

#write reg(8bit)
proc i2c_write_reg8 {slave_addr reg data }  {
	i2c_init
	i2c_start $slave_addr 0 0 
	i2c_write $reg 0
	i2c_write $data 1	
	i2c_close	
} 

#main function

#target correct master service path
set result  0
set i2c_test_case "I2C TOPOLOGY TARGET DEVICE ACCESS TEST"
puts "\n$i2c_test_case\n"
#set board_usb_port_no    $env(board_usb_port_no)
#set board_device_no      $env(board_device_no)
set board_usb_port_no     1
set board_device_no       1
set i2c_slave_address     0x0
set isRead                0
set isRestart             0
set isstop                1

set service_path [master_service_path_target $board_usb_port_no $board_device_no];
puts "current service path: $service_path\n"
open_service master $service_path
puts "open service -> [is_service_open master $service_path]\n"

puts "---------------------------------------";
puts "I2C devices are listed below:"
puts "---------------------------------------";

      for {set i 0} {$i < [expr 0x80 - $i2c_slave_address]} {incr i 1} {
			set ack_bit [i2c_scan [format 0x%x [expr $i2c_slave_address+$i]] $isRead $isRestart $isstop]
			format $ack_bit; 
			if { $ack_bit == 0 } {
			   puts "slave address: [format 0x%x [expr $i2c_slave_address+$i]]\n"
			}
		}


#close master service
close_service master $service_path
puts "close service -> [is_service_open master $service_path]\n"
#----------------------------------------------------------------------------------------------------------------------
#result
return $result
