// INTEL CONFIDENTIAL
// Copyright 2019 Intel Corporation.  All Rights Reserved.
//
// The source code contained or described herein and all documents related
// to the source code ("Material") are owned by Intel Corporation or its
// suppliers or licensors. Title to the Material remains with Intel
// Corporation or its suppliers and licensors. The Material contains trade
// secrets and proprietary and confidential information of Intel or its
// suppliers and licensors. The Material is protected by worldwide copyright
// and trade secret laws and treaty provisions. No part of the Material may
// be used, copied, reproduced, modified, published, uploaded, posted,
// transmitted, distributed, or disclosed in any way without Intel's prior
// express written permission.
//
// No license under any patent, copyright, trade secret or other intellectual
// property right is granted to or conferred upon you by disclosure or
// delivery of the Materials, either expressly, by implication, inducement,
// estoppel or otherwise. Any license under such intellectual property rights
// must be express and approved by Intel in writing.

`timescale 1ns / 100ps

module  filter_circuit #(
        parameter	         FILTER_WIDTH = 8, // even number: 2, 4, 6, 8 ...
        parameter            INIT_BIT     = 1
        )
        (
         input   wire        i_clk_rst       , // reset
         input   wire        i_clk           , // clock
         input   wire        i_framein       , // input
         output  wire        o_frameout        // output
         );

//--------------------------------------------------
// Signal defination
//--------------------------------------------------

wire                         initbit    ; // 
reg      [FILTER_WIDTH-1:0]  fr_shifter ; // 
reg                          frameout   ; // 
wire                         fr_posedge ; // 
wire                         fr_negedge ; // 

//--------------------------------------------------
// Main function body
//--------------------------------------------------

// Output assignments
assign o_frameout = frameout;

// input posedge/negedge detection
assign fr_posedge = (&(~fr_shifter[FILTER_WIDTH-1:FILTER_WIDTH/2])) && (&(fr_shifter[FILTER_WIDTH/2-1:0])); // posedge detection
assign fr_negedge = (&(fr_shifter[FILTER_WIDTH-1:FILTER_WIDTH/2])) && (&(~fr_shifter[FILTER_WIDTH/2-1:0])); // negedge detection

////////////////////////////////////////////////////////
// Left shifter control
always @(posedge i_clk or posedge i_clk_rst)
begin
  if(i_clk_rst)
    fr_shifter <= {FILTER_WIDTH{1'b0}};
  else
    fr_shifter <= {fr_shifter[FILTER_WIDTH-2:0], i_framein};
end

////////////////////////////////////////////////////////
// Filter output control
assign initbit = (INIT_BIT == 1) ? 1'b1 : 1'b0;

always @(posedge i_clk or posedge i_clk_rst)
begin
  if(i_clk_rst)
    frameout <= initbit;
  else if(&fr_shifter)
    frameout <= 1'b1;
  else if(fr_negedge)
    frameout <= 1'b0;
  else
    frameout <= frameout;
end

endmodule
//------------------------------------------------------------------------------
// end of file
//------------------------------------------------------------------------------