// INTEL CONFIDENTIAL
// Copyright 2019 Intel Corporation.  All Rights Reserved.
//
// The source code contained or described herein and all documents related
// to the source code ("Material") are owned by Intel Corporation or its
// suppliers or licensors. Title to the Material remains with Intel
// Corporation or its suppliers and licensors. The Material contains trade
// secrets and proprietary and confidential information of Intel or its
// suppliers and licensors. The Material is protected by worldwide copyright
// and trade secret laws and treaty provisions. No part of the Material may
// be used, copied, reproduced, modified, published, uploaded, posted,
// transmitted, distributed, or disclosed in any way without Intel's prior
// express written permission.
//
// No license under any patent, copyright, trade secret or other intellectual
// property right is granted to or conferred upon you by disclosure or
// delivery of the Materials, either expressly, by implication, inducement,
// estoppel or otherwise. Any license under such intellectual property rights
// must be express and approved by Intel in writing.

`timescale 1ns / 100ps

module  max_pgm_sel
        (
        input   wire       i_reset_n         , // reset
        input   wire       i_sys_clk         , // clock
        input   wire       i_pgm_sel_disable , // Page selection disable during configuration
        input   wire [3:0] i_page_sel_gui    , // Page selection via GUI
        input   wire       i_factory_load    , // Factory load setting
        input   wire       i_pgm_sel         , // Flash page selection pb
        output  wire [2:0] o_pgm_led         , // LED indication
        output  wire       o_pgm_sel_pb_trig , // Page_sel pb negedge to clear i_page_sel_gui[3]
        output  wire [2:0] o_fpga_pgm          // FPGA programming page selection
        );

//--------------------------------------------------
// Signal defination
//--------------------------------------------------

wire                 pgm_sel/* synthesis keep="1" */; 
wire                 pgm_sel_neg/* synthesis keep="1" */;
wire       [1:0]     fpga_pgm_cnt_init/* synthesis keep="1" */;  
wire       [2:0]     pgm_led_init/* synthesis keep="1" */;
wire       [2:0]     fpga_pgm_init/* synthesis keep="1" */;
reg                  pgm_sel_reg/* synthesis preserve = 1 */;
reg        [1:0]     fpga_pgm_cnt/* synthesis preserve = 1 */;  
reg        [2:0]     pgm_led/* synthesis preserve = 1 */;
reg        [2:0]     fpga_pgm/* synthesis preserve = 1 */;

//--------------------------------------------------
// Main function body
//--------------------------------------------------
assign fpga_pgm_cnt_init = i_factory_load ? 2'd1 : 2'd0;
assign pgm_led_init      = i_factory_load ? 3'b101 : 3'b110;
assign fpga_pgm_init     = i_factory_load ? 3'b001 : 3'b000;

assign o_pgm_led  = pgm_led;
assign o_fpga_pgm = fpga_pgm;
assign o_pgm_sel_pb_trig = pgm_sel_neg;  // For GUI to clear flag
assign pgm_sel_neg = pgm_sel_reg & (!i_pgm_sel); // negedge of pgm_sel

always @(posedge i_sys_clk or negedge i_reset_n)
begin
  if(!i_reset_n)
    pgm_sel_reg <= 1'b1;
   else     
    pgm_sel_reg <= i_pgm_sel;
end 

always @(posedge i_sys_clk or negedge i_reset_n)
begin
  if(!i_reset_n)
    fpga_pgm_cnt <= fpga_pgm_cnt_init;
  else if(i_pgm_sel_disable)                   // No change during PFL configuration
    fpga_pgm_cnt <= fpga_pgm_cnt;
  else if(pgm_sel_neg)
    begin
	//  if(fpga_pgm_cnt == 2'd2)
    //    fpga_pgm_cnt <= 2'd0;
	//  else
        fpga_pgm_cnt <= fpga_pgm_cnt + 1'd1;
    end
  else if(i_page_sel_gui[3])
    fpga_pgm_cnt <= i_page_sel_gui[1:0];      // Valid page selection: 0, 1, 2, 3	 
  else
    fpga_pgm_cnt <= fpga_pgm_cnt;
end

always @(posedge i_sys_clk or negedge i_reset_n)
begin
  if(!i_reset_n)
    begin
      pgm_led  <= pgm_led_init;
      fpga_pgm <= fpga_pgm_init;
    end
  else if(fpga_pgm_cnt == 2'd0)
    begin
      pgm_led  <= 3'b110;    //led0 is on
      fpga_pgm <= 3'b000;
    end
  else if(fpga_pgm_cnt == 2'd1)
    begin
      pgm_led  <= 3'b101;   //led1 is on
      fpga_pgm <= 3'b001;
    end
  else if(fpga_pgm_cnt == 2'd2)
    begin
      pgm_led  <= 3'b011;   //led2 is on
      fpga_pgm <= 3'b010;
    end
  else if(fpga_pgm_cnt == 2'd3)
    begin
      pgm_led  <= 3'b001;  //led2&1 are on
      fpga_pgm <= 3'b011;
    end
  else                                         
    begin
      pgm_led  <= pgm_led;                      
      fpga_pgm <= fpga_pgm;           
    end
end

endmodule
//------------------------------------------------------------------------------
// end of file
//------------------------------------------------------------------------------