//Filename: sgpio_master.v
//Anthor: Anna Gu
//Description: synchronized serial interface with four signals, act as master
//revision: 1.0
//revision history: 21-3-1
 
module sgpio_master (
  input         i_clk,         //50MHz
  input         i_rstn,
  input[7:0]    i_data_mosi,   //the value of data that master sends to slave 
  output[7:0]   o_data_miso,  //the value of data that master gets from slave 
  input         i_miso,      //master input slave output of the synchronized serial interface
  output        o_clk,       //clock of the synchronized serial interface driven by master
  output        o_sync,      //frame start of the synchronized serial interface, =1: the start of a frame  
  output        o_mosi       //master output slave input of the synchronized serial interface
);


  wire      clk_10m;
  wire      S_pll_locked;
  reg [2:0] bit_num;
  reg [7:0] S_mosi_shift;
  reg [7:0] S_miso_shift;
  reg       S_o_sync;
  wire      S_o_clk;
  reg [7:0] S_o_data_miso;
  wire      S_rstn;
  reg [7:0] S_data_mosi_d1;
  reg [7:0] S_data_mosi_d2;

  assign S_rstn     = i_rstn & S_pll_locked;
  assign o_clk      = S_pll_locked ? S_o_clk : 1'b0;
  assign o_sync     = S_o_sync;
  assign o_mosi     = S_mosi_shift[0];
  assign o_data_miso = S_o_data_miso;

 alt_pll_50m_10m pll_inst(
	.areset (1'b0),        
	.inclk0 (i_clk),
	.c0     (clk_10m), //10M
	.c1     (S_o_clk), //10M, 180degree shift
	.locked (S_pll_locked)
	);	

always @(posedge clk_10m or negedge S_rstn)
  begin
    if(!S_rstn) 
	  bit_num   <= 3'd0;
    else
	  bit_num   <= bit_num + 1'b1;
  end

always @(posedge clk_10m or negedge S_rstn)
  begin
    if(!S_rstn) begin
	  S_data_mosi_d1   <= 8'd0;
	  S_data_mosi_d2   <= 8'd0;
	end
    else begin 
	  S_data_mosi_d1   <= i_data_mosi;
	  S_data_mosi_d2   <= S_data_mosi_d1;
	end
  end
  
always @(posedge clk_10m or negedge S_rstn)
  begin
    if(!S_rstn) begin
	   S_mosi_shift <= 8'd0;
	   S_o_sync <= 1'b0;
	 end
    else if (bit_num == 3'b000) begin 
	   S_mosi_shift <= S_data_mosi_d2;
	   S_o_sync       <= 1'b1;
	 end		
	 else begin
		S_mosi_shift <= {1'b0, S_mosi_shift[7:1]};
		S_o_sync       <= 1'b0;
	 end
  end
	
 always @(posedge clk_10m or negedge S_rstn)
  begin
    if(!S_rstn) 
	   S_miso_shift  <= 8'hff;
	 else 
	   S_miso_shift <= {i_miso, S_miso_shift[7:1]};
  end
  
  always @(posedge clk_10m or negedge S_rstn)
  begin
    if(!S_rstn) 
	   S_o_data_miso <= 8'hff;
	 else if (S_o_sync) 
	   S_o_data_miso <= S_miso_shift;
	 else 
	   S_o_data_miso <= S_o_data_miso;
  end
 
endmodule
