// INTEL CONFIDENTIAL
// Copyright 2024 Intel Corporation.  All Rights Reserved.
//
// The source code contained or described herein and all documents related
// to the source code ("Material") are owned by Intel Corporation or its
// suppliers or licensors. Title to the Material remains with Intel
// Corporation or its suppliers and licensors. The Material contains trade
// secrets and proprietary and confidential information of Intel or its
// suppliers and licensors. The Material is protected by worldwide copyright
// and trade secret laws and treaty provisions. No part of the Material may
// be used, copied, reproduced, modified, published, uploaded, posted,
// transmitted, distributed, or disclosed in any way without Intel's prior
// express written permission.
//
// No license under any patent, copyright, trade secret or other intellectual
// property right is granted to or conferred upon you by disclosure or
// delivery of the Materials, either expressly, by implication, inducement,
// estoppel or otherwise. Any license under such intellectual property rights
// must be express and approved by Intel in writing.

module max10_system( 
  input        clk_50m_sysmax       , //50MHz global clock
  input        sys_max_resetn_conf_done    , //reset from CONF_DONE of system max10，~520us delay from CONF_DONE
  
  inout        sdm_io11             , //hps_cold_resetn 
  output       sys_pwr_rsv2         , //hard_power_cycle_pb
  
 // input        hps_sw_rstn          , //from ubiipwr max10
  input        hps_hw_rstn          , //from ubiipwr max10 
  output       fc_rstn             , //flash dc reset for as mode
 // input        fc_prsntn           , //flash dc presetn 
  output       fpga_resetn         ,
  input        sys_pwr_ok          , //from ubiipwr max10 
  output       s2p_ovtmp_n         , //to ubiipwr max10
  input        overtemp_n          ,
  
/*PCIe*/
//PCIe MCIO functions as pcie ep or pcie rp
  inout        pcie_perstn_a   ,  //related to F-Tile bank13A
 // output       pcie_alertn_a   ,  //reserved 
  inout        pcie_scl_a      ,   
  inout        pcie_sda_a      ,  
  
//fmc functions as pcie ep or pcie rp
  inout        fmca_pcie_perstn_3v3 , //related to F-Tile bank12C
  inout        fmcb_pcie_perstn_3v3 , //related to F-Tile bank12A
 // output       pcie_waken_3v3  , //Reserved

//F_TILE
 // output       clk_gxf_io_pll ,  //fmc_a, reserved
  output       r_13a_perst_io_n ,
  //output       r_13c_spare_io_n ,  //reserved
  output       r_12a_perst_io_n ,    //fmc_b
  output       r_12c_perst_io_n ,    //fmc_a
  output       ca_13c_gxf_io_dfx_1 ,  
  
/*I2C*/
  inout        sdm_i2c_scl      ,   
  inout        sdm_i2c_sda      , 
  output       sdm_i2c_en   ,

  inout        pmb_i2c_scl      ,   
  inout        pmb_i2c_sda      ,  
 // input        pmb_alertn   ,
  
  inout        tsns_i2c_sda      ,   //MAX10 master
  inout        tsns_i2c_scl      , 
  
  inout        ivsns_i2c_scl ,
  inout        ivsns_i2c_sda ,
  
  inout        vcxo_i2c_sda      ,   //MAX10 master
  inout        vcxo_i2c_scl      , 
  output       zl_i2c_en   ,  //active high
  
  inout        clk_i2c_scl      ,   
  inout        clk_i2c_sda      , 
  output       clk_i2c_en0   ,  //active high
  output       clk_i2c_en1   ,  //active high

  inout        fmca_i2c_sda      ,   //MAX10 master when FM87 as RP
  inout        fmca_i2c_scl      ,   //MAX10 slave when FM87 as EP
  
  inout        fmcb_i2c_sda      ,   //MAX10 master when FM87 as RP
  inout        fmcb_i2c_scl      ,   //MAX10 slave when FM87 as EP
  
  inout        sys_max10_i2c_scl      ,   //MAX10 master
  inout        sys_max10_i2c_sda      ,

  inout        sys_pwr_rsv0  ,   //max_scl
  inout        sys_pwr_rsv1  ,   //max_sda
  
 // inout        tusb1146_scl  ,  //reserved
 // inout        tusb1146_sda  ,

/*clock control signals*/
 // output       pwm_vcxo      , //reserved
  output       vcxo_fs_3v3   ,
  input        vcxo_fs_1v2   ,
  input        fm_vcxo_inc   , 
  input        fm_vcxo_dec   ,

  
  output       si5391_oen  ,  //active low
  output       si5391_rstn  ,  //active low 
  output       si5391_b_oen  ,  //active low
  output       si5391_b_rstn  ,  //active low 
  
  output       si5394_rstn  ,  //active low
  output       si5394_oe_n  ,  //active low 
  input        si5394_lol   ,  //high: DSPLL is locked; low:out of lock
  input        si5394_int_n , 
  
  output [2:0] si5332_1_in , 
 
  input        gpio0_ac0_zl_intn , 
  output        ptp_clk_rst_n , 
  input        ptp_clk_lol ,  
  
  output [14:0] mux_sel, //select clock source
  output       mux_sel_zl,
  //output       mux_sel_vcxo,
  
  output       mcio_clk_sel_epn,
  output       mcio_clk_enn,

/*DDR4 DIMM*/
  output       dimm_io_en    ,  //active high
  
/*USB*/ 
  
  output       usb_mux_reset  ,

  output       usb2_resetn      ,  
  
/*fan control signals*/
  output       fan_rpm       ,
  //output       opt_fan_rpm   ,  //reserved

/*SGP between system max10 and fm85*/
  output       fm_sysmax_clk  , 
  output       fm_sysmax_sync ,
  output       fm_sysmax_fimo ,
  input        fm_sysmax_fomi ,  

/*GPIO Between system max10 and fm85*/
  inout [12:0] f_gpio ,

/*AVST*/
 //QSPI                                   
  output       qspi_rstn       , 
  inout        qspi_d0        , //QSPI_IO0
  inout        qspi_d1        , //QSPI_IO1
  inout        qspi_d2        , //QSPI_IO2
  inout        qspi_d3        , //QSPI_IO3
  output       qspi_csn        , //QSPI_SS0 
  output       qspi_sclk        , //QSPI_CLK
  
//Flash+configuration
  input [2:0]  fpga_msel            , //MSEL invert bits  
  input        sdm_io16             , //FM85_CONFIG_DONE   
  input        avst_ready           ,
  output       avst_data_valid      ,
  output       avst_clk             ,
  output[31:0] avst_d               ,
  output       fpga_nconfig         ,
  input        fpga_nstatus         ,
  
 // inout        sdm_io0              , //pwr_scl   
  //inout        sdm_io12             , //pwr_sda  
  
/*SDM_IO*/
 /* inout        sdm_io1             ,  
  inout        sdm_io2             ,  
  inout        sdm_io3             ,  
  inout        sdm_io4             ,  
  inout        sdm_io5             ,  
  inout        sdm_io6             ,  
  inout        sdm_io7             ,  
  inout        sdm_io8             ,  
  inout        sdm_io9             ,  
  inout        sdm_io10            ,  	
  inout        sdm_io13            , 
  inout        sdm_io14            , 
  inout        sdm_io15            , */
  
  
/*SW, PB & LEDs*/
//system max10
  input [7:0]  sysmax_sw            , //DipSW
  output[5:0]  sysmax_led_g         , //Green Leds
  output[1:0]  sysmax_led_r         , //Yellow Leds
  input [5:0]  sysmax_pb            , //Push buttons
  input [11:0]  mux_dip_sw            , //DipSW
//user for fm85
  input [7:0]  user_sw            , //DipSW 
  output[5:0]  user_led_g         , //Green Leds
  output[1:0]  user_led_r         , //Yellow Leds
  input [1:0]  user_pb             //Push buttons
);
 
  localparam  proj_id           = 16'h4187;    // ASIC A(gilex)87
  localparam  PCB_VERSION       = 8'h42     ;  // PCB version (ASCII code): Rev B
  localparam  MAX10_VERSION     = 24'h010008;  // System MAX10 Revision:
                                               // 24'h010001: original build
                                               // 24'h010002: ca_13c_gxf_io_dfx_1 is controlled by S_control_gui[17] instead of reserved
                                               // 24'h010003: make user_led_r[1] reserve instead of out of lock
                                               // 24'h010004: add PCB version info, update sdc
                                               // 24'h010005: update sdc
                                               // 24'h010006: update to QII22.1std 
                                               // 24'h010007: Change default value of register control_gui from 0xaa47 to 0x2aa4f
					                                // 24'h010008: use S_fpga_config_done_delay1ms to determine if vcxo_fs_3v3 is controlled by vcxo_fs_1v2 or not. 
                                               
                                            

  localparam pg_fpga_delay_cnt       = 16'h1388;   // 5000 x 20.48us = 102.4ms  
  localparam fpga_config_done_delay_cnt = 7'h64;   // 100 x 20.48us = 2.048ms   
  
  reg[9:0]  S_clk_div_cnt/* synthesis keep */;
  reg[15:0] S_pg_fpga_delay_cnt/* synthesis keep */;							   
  reg       S_pg_fpga_delay100ms/* synthesis keep */;	
  wire      S_clk_div_1024_pulse/* synthesis keep */;	
  reg [6:0] S_fpga_config_done_delay_cnt;
  reg       S_fpga_config_done_delay1ms;
  
  wire      system_max_resetn; 
  wire      system_max_resetn1; 
  wire      system_max_power_resetn;
  wire      S_hps_crstn;
  
  wire      pfl_nreset;
  wire      pgm_config;
  wire      pgm_sel;
  wire[2:0] fpga_msel_invert;
  wire      avst_mode/* synthesis keep */;
  wire[31:0] S_control_gui;
  wire      S_cpu_resetn_gui;
  wire      S_fpga_reconfign_gui;
  wire[3:0] S_page_sel_gui;
  wire      S_pgm_sel_pb_trig;
  wire      S_max_conf_donen;
  wire      S_max_loadn;
  wire      S_max_errorn;
  wire[2:0] S_pgm_led;
  wire[2:0] S_fpga_page;
  wire      S_fpga_resetn;
 // wire[7:0] S_filtered_sysmax_sw;
  wire[5:0] S_filtered_sysmax_pb/* synthesis keep */;
  wire[1:0] S_filtered_user_pb;
  //wire[7:0] S_filtered_user_sw;
  wire      factory_load;
  
  wire[2:0] pwm_duty_ctrl;
  wire      fan_cont_out; 

  wire      sdm_i2c_sda_in;      //system -> vccl power ic
  wire      sdm_i2c_scl_in; 
  wire      sdm_i2c_sda_oe; 
  wire      sdm_i2c_scl_oe; 
  
  wire      pmb_i2c_sda_in;      //system -> power ics
  wire      pmb_i2c_scl_in; 
  wire      pmb_i2c_sda_oe; 
  wire      pmb_i2c_scl_oe; 
  
  wire      tsns_i2c_sda_in;      //system -> temp sensors
  wire      tsns_i2c_scl_in; 
  wire      tsns_i2c_sda_oe; 
  wire      tsns_i2c_scl_oe; 
  
  wire      ivsns_i2c_sda_in;      //system -> IV sensors
  wire      ivsns_i2c_scl_in; 
  wire      ivsns_i2c_sda_oe; 
  wire      ivsns_i2c_scl_oe;  
  
  wire      vcxo_i2c_sda_in;      //system -> VCXO
  wire      vcxo_i2c_scl_in; 
  wire      vcxo_i2c_sda_oe; 
  wire      vcxo_i2c_scl_oe;  
  
  wire      clk_i2c_sda_in;      //system -> CLOCK ICs 
  wire      clk_i2c_scl_in; 
  wire      clk_i2c_sda_oe; 
  wire      clk_i2c_scl_oe; 
  
  wire      fmca_i2c_m_sda_in;        //fm87 as RP, system -> FMCA 
  wire      fmca_i2c_m_scl_in; 
  wire      fmca_i2c_m_sda_oe; 
  wire      fmca_i2c_m_scl_oe; 
  
  wire      fmcb_i2c_m_sda_in;        //fm87 as RP, system -> FMCB 
  wire      fmcb_i2c_m_scl_in; 
  wire      fmcb_i2c_m_sda_oe; 
  wire      fmcb_i2c_m_scl_oe;
  
  wire      fmca_i2c_s_sda_in;        //fm87 as EP, FMCA ->  system
  wire      fmca_i2c_s_scl_in; 
  wire      fmca_i2c_s_sda_oe; 
  wire      fmca_i2c_s_scl_oe; 
  
  wire      fmcb_i2c_s_sda_in;        //fm87 as EP, FMCB -> system 
  wire      fmcb_i2c_s_scl_in; 
  wire      fmcb_i2c_s_sda_oe; 
  wire      fmcb_i2c_s_scl_oe;
  
  wire      sys_max10_i2c_sda_in;        //system -> USB PD Controller
  wire      sys_max10_i2c_scl_in; 
  wire      sys_max10_i2c_sda_oe; 
  wire      sys_max10_i2c_scl_oe;
  
  wire      ubiipwr_max_i2c_sda_in;  //system -> Power max10
  wire      ubiipwr_max_i2c_scl_in; 
  wire      ubiipwr_max_i2c_sda_oe; 
  wire      ubiipwr_max_i2c_scl_oe; 
  
 
  wire      bmc_s_sda_in;               //pcie ep                                       
  wire      bmc_s_scl_in;                                                        
  wire      bmc_s_smbus_sda_oe;                                                        
  wire      bmc_s_smbus_scl_oe;
  
  wire      bmc_m_sda_in;              //pcie rp                                          
  wire      bmc_m_scl_in;                                                        
  wire      bmc_m_smbus_sda_oe;                                                        
  wire      bmc_m_smbus_scl_oe;
  
  
  wire[15:0] dac_i2c_access_state;
  wire[15:0] dac_i2c_read_data;
  wire       dac_i2c_access_start;

  wire[31:0] status_gui;
  
  wire       S_clr_inc_dec; 
  wire       S_inc_decn;
  wire[10:0] S_inc_dec_num;
  wire       S_fm_vcxo_dec;
  wire       S_fm_vcxo_inc;
  
  wire       S_fm_sysmax_clk;
  wire       S_fm_sysmax_sync;
  wire       S_fm_sysmax_fimo;
  wire[7:0]  S_user_led;
  
  wire[15:0]  mux_sel_gui_en;
  wire[15:0]  mux_sel_gui_set;
  
  wire[31:0]	 system_info_slv_data_write_0;
  wire[31:0]	 system_info_slv_data_write_1;
  

  wire       fmca_pcie_perstn_rp;
  wire       fmca_pcie_perstn;
  wire       fmca_pcie_ep_rpn;
  
  wire       fmcb_pcie_perstn_rp;
  wire       fmcb_pcie_perstn;
  wire       fmcb_pcie_ep_rpn;
  
  wire       mcio_pcie_perstn_rp;
  wire       mcio_pcie_perstn;
  wire       mcio_pcie_ep_rpn;
  wire       S_mcio_clk_sel_epn;
  

  assign fc_rstn       = 1'bZ;
  assign qspi_rstn     = 1'bZ; 
  assign sdm_io11      = S_hps_crstn ? 1'bZ : 1'b0;  

  assign dac_i2c_access_start = S_control_gui[0]; 
  assign clk_i2c_en1          = 1'b0;
  assign sdm_i2c_en           = sys_pwr_ok ? S_control_gui[1] : 1'b0; //=1 by default 
  assign dimm_io_en           = sys_pwr_ok;
  assign clk_i2c_en0          = sys_pwr_ok ? S_control_gui[2] : 1'b0; //=1 by default 
  assign zl_i2c_en            = sys_pwr_ok ? S_control_gui[3] : 1'b0; //=0 by default 
  assign si5332_1_in[1:0]     = S_control_gui[5:4];
  assign si5332_1_in[2]       = 1'bZ; 
  assign ptp_clk_rst_n        = sys_pwr_ok ? S_control_gui[6] : 1'b0; //=1 by default;
  assign mcio_clk_enn         = sys_pwr_ok ? S_control_gui[7] : 1'b1; //=0 by default;
  assign S_mcio_clk_sel_epn   = mcio_pcie_ep_rpn ? 1'b0 : 1'b1;
  assign mcio_clk_sel_epn     = system_info_slv_data_write_0[16] ? S_control_gui[8] : S_mcio_clk_sel_epn; //=0 by default;  
  assign si5391_rstn          = sys_max_resetn_conf_done ? S_control_gui[9] : 1'b0; //=1 by default;
  assign si5391_oen           = sys_pwr_ok ? S_control_gui[10] : 1'b1; //=0 by default; 
  assign si5391_b_rstn        = sys_max_resetn_conf_done ? S_control_gui[11] : 1'b0; //=1 by default;;
  assign si5391_b_oen         = sys_pwr_ok ? S_control_gui[12] : 1'b1; //=0 by default; 
  assign si5394_rstn          = sys_max_resetn_conf_done ? S_control_gui[13] : 1'b0; //=1 by default;;
  assign si5394_oe_n          = sys_pwr_ok ? S_control_gui[14] : 1'b1; //=0 by default; 
  assign usb2_resetn          = sys_pwr_ok ? S_control_gui[15] : 1'b0; //=1 by default; 
  assign usb_mux_reset        = sys_pwr_ok ? S_control_gui[16] : 1'b1; //=0 by default;
  assign ca_13c_gxf_io_dfx_1  = sys_pwr_ok ? S_control_gui[17] : 1'b0; //=1 by default;
  
  assign mux_sel[0]      = mux_sel_gui_en[0] ? mux_sel_gui_set[0] : mux_dip_sw[10];
  assign mux_sel[1]      = mux_sel_gui_en[1] ? mux_sel_gui_set[1] : sysmax_sw[1];
  assign mux_sel[2]      = mux_sel_gui_en[2] ? mux_sel_gui_set[2] : mux_dip_sw[0];
  assign mux_sel[3]      = mux_sel_gui_en[3] ? mux_sel_gui_set[3] : mux_dip_sw[1];
  assign mux_sel[4]      = mux_sel_gui_en[4] ? mux_sel_gui_set[4] : mux_dip_sw[2];
  assign mux_sel[5]      = mux_sel_gui_en[5] ? mux_sel_gui_set[5] : mux_dip_sw[3];
  assign mux_sel[6]      = mux_sel_gui_en[6] ? mux_sel_gui_set[6] : mux_dip_sw[9];
  assign mux_sel[7]      = mux_sel_gui_en[7] ? mux_sel_gui_set[7] : sysmax_sw[2];
  assign mux_sel[8]      = mux_sel_gui_en[8] ? mux_sel_gui_set[8] : mux_dip_sw[11];
  assign mux_sel[9]      = mux_sel_gui_en[9] ? mux_sel_gui_set[9] : sysmax_sw[3];
  assign mux_sel[10]     = mux_sel_gui_en[10] ? mux_sel_gui_set[10] : mux_dip_sw[4];
  assign mux_sel[11]     = mux_sel_gui_en[11] ? mux_sel_gui_set[11] : mux_dip_sw[5];
  assign mux_sel[12]     = mux_sel_gui_en[12] ? mux_sel_gui_set[12] : mux_dip_sw[6];
  assign mux_sel[13]     = mux_sel_gui_en[13] ? mux_sel_gui_set[13] : mux_dip_sw[8];
  assign mux_sel[14]     = mux_sel_gui_en[14] ? mux_sel_gui_set[14] : mux_dip_sw[7];
  assign mux_sel_zl      = mux_sel_gui_en[15] ? mux_sel_gui_set[15] : sysmax_sw[4];
  //assign mux_sel_vcxo    = 1'b0;
  assign mux_sel_gui_en  = system_info_slv_data_write_0[15:0];
  assign mux_sel_gui_set = system_info_slv_data_write_1[15:0];
   
 // assign vcxo_fs_3v3     = sdm_io16 ? vcxo_fs_1v2     : 1'b0 ;  //sdm_io16 pull-down interally 
  assign vcxo_fs_3v3     = S_fpga_config_done_delay1ms ? vcxo_fs_1v2     : 1'b0 ;
  
  assign status_gui      ={21'd0,si5391_rstn, si5391_oen, si5391_b_rstn, si5391_b_oen, ptp_clk_rst_n, si5394_rstn, si5394_oe_n, si5394_lol, si5394_int_n, ptp_clk_lol, gpio0_ac0_zl_intn };
  
  assign s2p_ovtmp_n     = overtemp_n;

//-----------------------------------------------------------------------------------------------------------------
  // system max PB
  //-----------------------------------------------------------------------------------------------------------------
  assign system_max_resetn1 = sys_max_resetn_conf_done & S_filtered_sysmax_pb[0]; 
  assign system_max_resetn  = sys_pwr_ok & S_filtered_sysmax_pb[0]; 
  assign system_max_power_resetn  = sys_pwr_ok & S_filtered_sysmax_pb[0] & sdm_io16; 
  
  assign fpga_resetn        = sys_pwr_ok ? (S_fpga_resetn && S_filtered_sysmax_pb[1]) : 1'bz;
  assign sys_pwr_rsv2       = S_filtered_sysmax_pb[3]; //power recycle
  assign S_hps_crstn        = sys_pwr_ok ? (S_filtered_sysmax_pb[2] & hps_hw_rstn): 1'b0 ; //hps cold reset
  assign pgm_sel            = S_filtered_sysmax_pb[4];
  assign pgm_config         = S_filtered_sysmax_pb[5];   
  
  //filter push button
   pb_filter #(
    .FILTER_WIDTH       (6'd8), 
    .INIT_BIT           (1'b1))
  pb_filter_inst(
    .I_reset_n          (sys_max_resetn_conf_done),  //don't use system_max_resetn, otherwise sysmax_pb[0] will be affected 
    .I_clk              (clk_50m_sysmax  	   ),
    .I_user_pb          (sysmax_pb           ),
    .O_filtered_user_pb (S_filtered_sysmax_pb) 
  ); 

  //-----------------------------------------------------------------------------------------------------------------
  // system max SW
  //-----------------------------------------------------------------------------------------------------------------

  assign factory_load       = sysmax_sw[0]; 
  assign fmca_pcie_ep_rpn   = sysmax_sw[5];
  assign fmcb_pcie_ep_rpn   = sysmax_sw[6];
  assign mcio_pcie_ep_rpn   = sysmax_sw[7];
  assign f_gpio[5]          = sdm_io16 ? sysmax_sw[3] : 1'bz; 

  //-----------------------------------------------------------------------------------------------------------------
  // system max led
  //-----------------------------------------------------------------------------------------------------------------
 
  //LED 0:ON, 1:OFF
  assign sysmax_led_g[2:0]  = S_pgm_led ;        // page indication
  assign sysmax_led_g[3]    = S_max_loadn ;      // ON while loading FPP design from flash
                                                //if AS mode, ON before conf_done is high
																//if pb[5]=0, it is ON
  assign sysmax_led_g[4]    = S_max_conf_donen ; // ON after PFL Configuration PASS or AS configuration pass
  assign sysmax_led_r[0]    = avst_mode ? S_max_errorn : 1'b1; //On if avst configuration failure
  assign sysmax_led_r[1]    = 1'b1;   //reserved
   
  //-----------------------------------------------------------------------------------------------------------------
  // user pb
  //-----------------------------------------------------------------------------------------------------------------
  assign f_gpio[0]          = sdm_io16 ? S_filtered_user_pb[0] : 1'bz;
  assign f_gpio[1]          = sdm_io16 ? S_filtered_user_pb[1] : 1'bz;  
  
  //filter push button
   filter_circuit      #(
    .FILTER_WIDTH             (6'd8), 
    .INIT_BIT                 (1'b1)  
    )                                               
    filter_circuit_user_pb_inst0                         
    (                                               
    .i_clk_rst                (!system_max_resetn    ), 
    .i_clk                    (clk_50m_sysmax        ), 
    .i_framein                (user_pb[0]            ), 
    .o_frameout               (S_filtered_user_pb[0] )  
    ); 
	 
  filter_circuit      #(
    .FILTER_WIDTH             (6'd8), 
    .INIT_BIT                 (1'b1)  
    )                                               
    filter_circuit_user_pb_inst1                        
    (                                               
    .i_clk_rst                (!system_max_resetn    ), 
    .i_clk                    (clk_50m_sysmax        ), 
    .i_framein                (user_pb[1]            ), 
    .o_frameout               (S_filtered_user_pb[1] )  
    ); 
  
   //-----------------------------------------------------------------------------------------------------------------
  // user sw, led
  //-----------------------------------------------------------------------------------------------------------------
 
  assign fm_sysmax_clk      = sdm_io16 ? S_fm_sysmax_clk  : 1'bz;
  assign fm_sysmax_sync     = sdm_io16 ? S_fm_sysmax_sync : 1'bz;
  assign fm_sysmax_fimo     = sdm_io16 ? S_fm_sysmax_fimo : 1'bz;

  assign user_led_g[5:0]    = sdm_io16 ? S_user_led[5:0] : 6'b111111;       
  assign user_led_r[1:0]    = sdm_io16 ? S_user_led[7:6] : 2'b11    ; 
  
 //send user_sw to FPGA and get user_led from FPGA via sgpio
  sgpio_master sgpio_master_inst(
    .i_clk       (clk_50m_sysmax    ),  
    .i_rstn      (system_max_resetn ),  
    .i_data_mosi (user_sw           ), 
	 .o_data_miso (S_user_led        ), 
	 .i_miso      (fm_sysmax_fomi    ), 
	 .o_clk       (S_fm_sysmax_clk   ),
	 .o_sync      (S_fm_sysmax_sync  ),
    .o_mosi      (S_fm_sysmax_fimo  )  
  );
  

//-----------------------------------------------------------------------------------------------------------------
  // PCIe
  //-----------------------------------------------------------------------------------------------------------------
 
 
  assign fmca_pcie_perstn_rp  = sdm_io16 ? f_gpio[3] : 1'b0;
  assign fmca_pcie_perstn     = fmca_pcie_ep_rpn ? fmca_pcie_perstn_3v3 : fmca_pcie_perstn_rp;
  assign fmca_pcie_perstn_3v3 = fmca_pcie_ep_rpn ? 1'bz : fmca_pcie_perstn_rp;
  assign r_12c_perst_io_n     = sys_pwr_ok ? fmca_pcie_perstn : 1'b0;
  
  assign fmca_i2c_s_scl_in    = fmca_pcie_ep_rpn ? fmca_i2c_scl : 1'b1; 
  assign fmca_i2c_s_sda_in    = fmca_pcie_ep_rpn ? fmca_i2c_sda : 1'b1;
  assign fmca_i2c_scl         = (fmca_pcie_ep_rpn && fmca_i2c_s_scl_oe) ? 1'b0 : 1'bZ;		 
  assign fmca_i2c_sda         = (fmca_pcie_ep_rpn && fmca_i2c_s_sda_oe) ? 1'b0 : 1'bZ;	 
  
  assign fmca_i2c_m_scl_in    = fmca_pcie_ep_rpn ? 1'b1 : fmca_i2c_scl ; 
  assign fmca_i2c_m_sda_in    = fmca_pcie_ep_rpn ? 1'b1 : fmca_i2c_sda ;
  assign fmca_i2c_scl         = (!fmca_pcie_ep_rpn && fmca_i2c_m_scl_oe) ? 1'b0 : 1'bZ;		 
  assign fmca_i2c_sda         = (!fmca_pcie_ep_rpn && fmca_i2c_m_sda_oe) ? 1'b0 : 1'bZ;	
  
  assign fmcb_pcie_perstn_rp  = sdm_io16 ? f_gpio[4] : 1'b0;
  assign fmcb_pcie_perstn     = fmcb_pcie_ep_rpn ? fmcb_pcie_perstn_3v3 : fmcb_pcie_perstn_rp;
  assign fmcb_pcie_perstn_3v3 = fmcb_pcie_ep_rpn ? 1'bz : fmcb_pcie_perstn_rp;  
  assign r_12a_perst_io_n     = sys_pwr_ok ? fmcb_pcie_perstn : 1'b0;
  
  assign fmcb_i2c_s_scl_in    = fmcb_pcie_ep_rpn ? fmcb_i2c_scl : 1'b1; 
  assign fmcb_i2c_s_sda_in    = fmcb_pcie_ep_rpn ? fmcb_i2c_sda : 1'b1;
  assign fmcb_i2c_scl         = (fmcb_pcie_ep_rpn && fmcb_i2c_s_scl_oe) ? 1'b0 : 1'bZ;		 
  assign fmcb_i2c_sda         = (fmcb_pcie_ep_rpn && fmcb_i2c_s_sda_oe) ? 1'b0 : 1'bZ;	 
  
  assign fmcb_i2c_m_scl_in    = fmcb_pcie_ep_rpn ? 1'b1 : fmcb_i2c_scl ; 
  assign fmcb_i2c_m_sda_in    = fmcb_pcie_ep_rpn ? 1'b1 : fmcb_i2c_sda ;
  assign fmcb_i2c_scl         = (!fmcb_pcie_ep_rpn && fmcb_i2c_m_scl_oe) ? 1'b0 : 1'bZ;		 
  assign fmcb_i2c_sda         = (!fmcb_pcie_ep_rpn && fmcb_i2c_m_sda_oe) ? 1'b0 : 1'bZ;
  
  assign mcio_pcie_perstn_rp  = sdm_io16 ? f_gpio[2] : 1'b0;
  assign mcio_pcie_perstn     = mcio_pcie_ep_rpn ? pcie_perstn_a : mcio_pcie_perstn_rp;
  assign pcie_perstn_a        = mcio_pcie_ep_rpn ? 1'bz : mcio_pcie_perstn_rp;
  assign r_13a_perst_io_n     = sys_pwr_ok ? mcio_pcie_perstn : 1'b0;

  assign bmc_s_scl_in        = mcio_pcie_ep_rpn ? pcie_scl_a : 1'b1 ;                   //pcie EP
  assign bmc_s_sda_in        = mcio_pcie_ep_rpn ? pcie_sda_a : 1'b1 ;
  assign pcie_scl_a        =  (mcio_pcie_ep_rpn && bmc_s_smbus_scl_oe) ? 1'b0 : 1'bz;
  assign pcie_sda_a        =  (mcio_pcie_ep_rpn && bmc_s_smbus_sda_oe) ? 1'b0 : 1'bz; 
  
  assign bmc_m_scl_in        = mcio_pcie_ep_rpn ? 1'b1 : pcie_scl_a;                   //pcie RP
  assign bmc_m_sda_in        = mcio_pcie_ep_rpn ? 1'b1 : pcie_sda_a;
  assign pcie_scl_a        =  (!mcio_pcie_ep_rpn && bmc_m_smbus_scl_oe) ? 1'b0 : 1'bz;
  assign pcie_sda_a        =  (!mcio_pcie_ep_rpn && bmc_m_smbus_sda_oe) ? 1'b0 : 1'bz; 
//-----------------------------------------------------------------------------------------------------------------
  // extra delay
  //-----------------------------------------------------------------------------------------------------------------
  
 assign S_clk_div_1024_pulse = (S_clk_div_cnt == 10'd1023) ? 1'b1: 1'b0; //20ns*1024=20.48us
  
  always @(posedge clk_50m_sysmax or negedge system_max_resetn)
  begin
    if(!system_max_resetn)
      S_clk_div_cnt <= 10'd0;
    else
      S_clk_div_cnt <= S_clk_div_cnt +1'b1;
  end
  
  always @(posedge clk_50m_sysmax or negedge system_max_resetn)
  begin
    if(!system_max_resetn) 
	  S_pg_fpga_delay100ms <= 1'b0;
	else if(S_pg_fpga_delay_cnt == pg_fpga_delay_cnt)
	  S_pg_fpga_delay100ms <= 1'b1;
	else
	  S_pg_fpga_delay100ms <= S_pg_fpga_delay100ms;
  end
  
  always @(posedge clk_50m_sysmax or negedge system_max_resetn)
  begin
    if(!system_max_resetn)
      S_pg_fpga_delay_cnt <= 16'd0;
    else if(S_clk_div_1024_pulse)
      begin
        if(S_pg_fpga_delay_cnt == pg_fpga_delay_cnt)
          S_pg_fpga_delay_cnt <= S_pg_fpga_delay_cnt;
        else
          S_pg_fpga_delay_cnt <= S_pg_fpga_delay_cnt +1'b1;
      end
    else
      S_pg_fpga_delay_cnt <= S_pg_fpga_delay_cnt;
  end
  
  always @(posedge clk_50m_sysmax or negedge system_max_power_resetn)
  begin
    if(!system_max_power_resetn) 
	  S_fpga_config_done_delay1ms <= 1'b0;
	else if(S_fpga_config_done_delay_cnt == fpga_config_done_delay_cnt)
	  S_fpga_config_done_delay1ms <= 1'b1;
	else
	  S_fpga_config_done_delay1ms <= S_fpga_config_done_delay1ms;
  end
  
  always @(posedge clk_50m_sysmax or negedge system_max_power_resetn)
  begin
    if(!system_max_power_resetn)
      S_fpga_config_done_delay_cnt <= 7'd0;
    else if(S_clk_div_1024_pulse & sdm_io16)
      begin
        if(S_fpga_config_done_delay_cnt == fpga_config_done_delay_cnt)
          S_fpga_config_done_delay_cnt <= S_fpga_config_done_delay_cnt;
        else
          S_fpga_config_done_delay_cnt <= S_fpga_config_done_delay_cnt +1'b1;
      end
    else
      S_fpga_config_done_delay_cnt <= S_fpga_config_done_delay_cnt;
  end
  
 //-----------------------------------------------------------------------------------------------------------------
  // Fan control interface: PWM Frequency 25KHz
  //-----------------------------------------------------------------------------------------------------------------
  fan_controller fan_ctrl_inst(
    .i_clk           (clk_50m_sysmax    ),  
    .i_reset_n       (system_max_resetn1),  
    .i_pwm_duty_ctrl (pwm_duty_ctrl     ), // Duty cycle control, 3'b100 (60%) by default
    .o_fan_cont_out  (fan_cont_out      )  // Fan control output, low active
    );
   
  assign fan_rpm = ((overtemp_n && fan_cont_out) == 1'b0) ? 1'b1 : 1'b0; // 1: Fan ON; 0: Fan OFF 
  
//-----------------------------------------------------------------------------------------------------------------
  // I2C
  //-----------------------------------------------------------------------------------------------------------------
 
  assign sdm_i2c_scl_in     = sdm_i2c_scl; 
  assign sdm_i2c_scl        = sdm_i2c_scl_oe ? 1'b0 : 1'bZ;		
  assign sdm_i2c_sda_in     = sdm_i2c_sda; 
  assign sdm_i2c_sda        = sdm_i2c_sda_oe ? 1'b0 : 1'bZ;	 
  
  assign pmb_i2c_scl_in     = pmb_i2c_scl; 
  assign pmb_i2c_scl        = pmb_i2c_scl_oe ? 1'b0 : 1'bZ;		
  assign pmb_i2c_sda_in     = pmb_i2c_sda; 
  assign pmb_i2c_sda        = pmb_i2c_sda_oe ? 1'b0 : 1'bZ;	
  
  assign tsns_i2c_scl_in    = tsns_i2c_scl; 
  assign tsns_i2c_scl       = tsns_i2c_scl_oe ? 1'b0 : 1'bZ;		
  assign tsns_i2c_sda_in    = tsns_i2c_sda; 
  assign tsns_i2c_sda       = tsns_i2c_sda_oe ? 1'b0 : 1'bZ;	
  
  assign ivsns_i2c_scl_in   = ivsns_i2c_scl; 
  assign ivsns_i2c_scl      = ivsns_i2c_scl_oe ? 1'b0 : 1'bZ;		
  assign ivsns_i2c_sda_in   = ivsns_i2c_sda; 
  assign ivsns_i2c_sda      = ivsns_i2c_sda_oe ? 1'b0 : 1'bZ;	

  assign vcxo_i2c_scl_in    = vcxo_i2c_scl; 
  assign vcxo_i2c_scl       = vcxo_i2c_scl_oe ? 1'b0 : 1'bZ;		
  assign vcxo_i2c_sda_in    = vcxo_i2c_sda; 
  assign vcxo_i2c_sda       = vcxo_i2c_sda_oe ? 1'b0 : 1'bZ;	

  assign clk_i2c_scl_in     = clk_i2c_scl; 
  assign clk_i2c_scl        = clk_i2c_scl_oe ? 1'b0 : 1'bZ;		
  assign clk_i2c_sda_in     = clk_i2c_sda; 
  assign clk_i2c_sda        = clk_i2c_sda_oe ? 1'b0 : 1'bZ;	  
  
  assign sys_max10_i2c_scl_in     = sys_max10_i2c_scl; 
  assign sys_max10_i2c_scl        = sys_max10_i2c_scl_oe ? 1'b0 : 1'bZ;		
  assign sys_max10_i2c_sda_in     = sys_max10_i2c_sda; 
  assign sys_max10_i2c_sda        = sys_max10_i2c_sda_oe ? 1'b0 : 1'bZ; 
  
  
  
  assign ubiipwr_max_i2c_scl_in = sys_pwr_rsv0; 
  assign sys_pwr_rsv0           = ubiipwr_max_i2c_scl_oe ? 1'b0 : 1'bZ;		
  assign ubiipwr_max_i2c_sda_in = sys_pwr_rsv1; 
  assign sys_pwr_rsv1           = ubiipwr_max_i2c_sda_oe ? 1'b0 : 1'bZ;	  
 
//-----------------------------------------------------------------------------------------------------------------
  // AVST configuration
  //-----------------------------------------------------------------------------------------------------------------

  assign pfl_nreset         = avst_mode ? S_pg_fpga_delay100ms : 1'b0; //high-enable fm87 configuration;
                                                                       //pull low when don't use PFL II IP core
																							  //this delay is a must to make sure FPGA is ready for configuration
  assign fpga_msel_invert   = {!fpga_msel[2],!fpga_msel[1],!fpga_msel[0]};
  assign avst_mode          = ((fpga_msel_invert == 3'b000) || (fpga_msel_invert == 3'b101) || (fpga_msel_invert == 3'b110)) ? 1'b1 : 1'b0; //AVST X32, X16, X8

  max_pfl_ctrl max_pfl_ctrl_inst( 
    .i_reset_n           (system_max_resetn   ),
    .i_pfl_nreset        (pfl_nreset          ),
    .i_system_clk        (clk_50m_sysmax      ),
    .i_clk_div_1024_pulse(S_clk_div_1024_pulse),
    .i_cpu_resetn_gui    (S_cpu_resetn_gui    ), //determine the value of o_cpu_resetn, the function is the same as S_filtered_sysmax_pb[1]
    .i_fpga_reconfign_gui(S_fpga_reconfign_gui), //the function is the same as S_filtered_sysmax_pb[5]
    .i_page_sel_gui      (S_page_sel_gui      ),
    .i_factory_load      (factory_load        ),
    .i_pgm_sel           (pgm_sel             ), //pb[4]
    .i_pgm_config        (pgm_config          ), //pb[5]
    .i_fpga_conf_done    (sdm_io16            ), //conf_done
    .i_fpga_nstatus      (fpga_nstatus        ),
    .flash_io0           (qspi_d0             ),
    .flash_io1           (qspi_d1             ),
    .flash_io2           (qspi_d2             ),
    .flash_io3           (qspi_d3             ),
    .flash_ncs           (qspi_csn            ),
    .flash_sck           (qspi_sclk           ),
    .o_avst_valid        (avst_data_valid     ),
    .i_avst_ready        (avst_ready          ),
    .o_avst_data         (avst_d              ),
    .o_avst_clk          (avst_clk            ),
    .o_fpga_nconfig      (fpga_nconfig        ),
    .o_max_conf_donen    (S_max_conf_donen    ),  //When 0, MAX loading done
    .o_max_loadn         (S_max_loadn         ),  //when 0, MAX is loading
    .O_max_errorn        (S_max_errorn        ),  //when 0, MAX AVST configuration failed or AS configuration failed
    .o_fpga_pgm          (S_fpga_page         ),  //current active page. 3bit
    .o_pgm_led           (S_pgm_led           ),  //3bit led for current active page
    .o_pgm_sel_pb_trig	 (S_pgm_sel_pb_trig   ),  //Page_sel pb negedge to clear i_page_sel_gui[3]
    .o_cpu_resetn        (S_fpga_resetn       )  //determined by i_cpu_resetn_gui and fpga_conf_done_pos
    );  
	 
//-----------------------------------------------------------------------------------------------------------------
  // system_info
  //-----------------------------------------------------------------------------------------------------------------

	 
 q_sys q_sys_inst(
  	.clk_clk                              (clk_50m_sysmax    ),  
  	.reset_reset_n                        (system_max_resetn1), 
  	.i2c_0_i2c_serial_sda_in              (sdm_i2c_sda_in    ),
  	.i2c_0_i2c_serial_scl_in              (sdm_i2c_scl_in    ),
  	.i2c_0_i2c_serial_sda_oe              (sdm_i2c_sda_oe    ),
  	.i2c_0_i2c_serial_scl_oe              (sdm_i2c_scl_oe    ),
	
  	.i2c_1_i2c_serial_sda_in              (pmb_i2c_sda_in    ),
  	.i2c_1_i2c_serial_scl_in              (pmb_i2c_scl_in    ),
  	.i2c_1_i2c_serial_sda_oe              (pmb_i2c_sda_oe    ),
  	.i2c_1_i2c_serial_scl_oe              (pmb_i2c_scl_oe    ),
	
  	.i2c_2_i2c_serial_sda_in              (tsns_i2c_sda_in   ),
  	.i2c_2_i2c_serial_scl_in              (tsns_i2c_scl_in   ),
  	.i2c_2_i2c_serial_sda_oe              (tsns_i2c_sda_oe   ),
  	.i2c_2_i2c_serial_scl_oe              (tsns_i2c_scl_oe   ),
	
  	.i2c_3_i2c_serial_sda_in              (ivsns_i2c_sda_in  ),
  	.i2c_3_i2c_serial_scl_in              (ivsns_i2c_scl_in  ),
  	.i2c_3_i2c_serial_sda_oe              (ivsns_i2c_sda_oe  ),
  	.i2c_3_i2c_serial_scl_oe              (ivsns_i2c_scl_oe  ),
	
  	.i2c_4_i2c_serial_sda_in              (vcxo_i2c_sda_in   ),
  	.i2c_4_i2c_serial_scl_in              (vcxo_i2c_scl_in   ),
  	.i2c_4_i2c_serial_sda_oe              (vcxo_i2c_sda_oe   ),
  	.i2c_4_i2c_serial_scl_oe              (vcxo_i2c_scl_oe   ),	
	
  	.i2c_5_i2c_serial_sda_in              (clk_i2c_sda_in    ),
  	.i2c_5_i2c_serial_scl_in              (clk_i2c_scl_in    ),
  	.i2c_5_i2c_serial_sda_oe              (clk_i2c_sda_oe    ),
  	.i2c_5_i2c_serial_scl_oe              (clk_i2c_scl_oe    ),		
	
  	.i2c_6_i2c_serial_sda_in              (fmca_i2c_m_sda_in    ),
  	.i2c_6_i2c_serial_scl_in              (fmca_i2c_m_scl_in    ),
  	.i2c_6_i2c_serial_sda_oe              (fmca_i2c_m_sda_oe    ),
  	.i2c_6_i2c_serial_scl_oe              (fmca_i2c_m_scl_oe    ),
	
	.i2c_7_i2c_serial_sda_in              (fmcb_i2c_m_sda_in    ),
  	.i2c_7_i2c_serial_scl_in              (fmcb_i2c_m_scl_in    ),
  	.i2c_7_i2c_serial_sda_oe              (fmcb_i2c_m_sda_oe    ),
  	.i2c_7_i2c_serial_scl_oe              (fmcb_i2c_m_scl_oe    ),
	
	.i2c_8_i2c_serial_sda_in              (sys_max10_i2c_sda_in    ),
  	.i2c_8_i2c_serial_scl_in              (sys_max10_i2c_scl_in    ),
  	.i2c_8_i2c_serial_sda_oe              (sys_max10_i2c_sda_oe    ),
  	.i2c_8_i2c_serial_scl_oe              (sys_max10_i2c_scl_oe    ),
	
	.i2c_9_i2c_serial_sda_in              (bmc_m_sda_in    ),
  	.i2c_9_i2c_serial_scl_in              (bmc_m_scl_in    ),
  	.i2c_9_i2c_serial_sda_oe              (bmc_m_smbus_sda_oe    ),
  	.i2c_9_i2c_serial_scl_oe              (bmc_m_smbus_scl_oe    ),
	
  	.i2c_power_max10_i2c_serial_sda_in    (ubiipwr_max_i2c_sda_in),
  	.i2c_power_max10_i2c_serial_scl_in    (ubiipwr_max_i2c_scl_in),
  	.i2c_power_max10_i2c_serial_sda_oe    (ubiipwr_max_i2c_sda_oe),
  	.i2c_power_max10_i2c_serial_scl_oe    (ubiipwr_max_i2c_scl_oe),
	
	.fmca_i2c_slave_conduit_end_conduit_data_in  (fmca_i2c_s_sda_in   ),
  	.fmca_i2c_slave_conduit_end_conduit_clk_in   (fmca_i2c_s_scl_in   ),
  	.fmca_i2c_slave_conduit_end_conduit_data_oe  (fmca_i2c_s_sda_oe   ),
  	.fmca_i2c_slave_conduit_end_conduit_clk_oe   (fmca_i2c_s_scl_oe   ),
	
	.fmcb_i2c_slave_conduit_end_conduit_data_in  (fmcb_i2c_s_sda_in   ),
  	.fmcb_i2c_slave_conduit_end_conduit_clk_in   (fmcb_i2c_s_scl_in   ),
  	.fmcb_i2c_slave_conduit_end_conduit_data_oe  (fmcb_i2c_s_sda_oe   ),
  	.fmcb_i2c_slave_conduit_end_conduit_clk_oe   (fmcb_i2c_s_scl_oe   ),
	
  	.pio_dipsw_external_connection_export        (sysmax_sw           ),
  	.pio_led_g_external_connection_export        (sysmax_led_g        ),              
  	.pio_led_y_external_connection_export        (sysmax_led_r        ),              
  	.pio_pb_external_connection_export           (S_filtered_sysmax_pb),
  	.pio_mux_dipsw_external_connection_export    (mux_dip_sw          ),
	
  	.system_max_id_0_control_gui_export          (S_control_gui       ),  
  	.system_max_id_0_cpu_resetn_export           (S_cpu_resetn_gui    ),  //bit0, default =1, write 0 will reset fpga, need to manually rewrite 1 to release fpga resetn
  	.system_max_id_0_fpga_pgm_export             (S_fpga_page         ),
  	.system_max_id_0_fpga_reconfign_export       (S_fpga_reconfign_gui), //bit0, default =1, write 0 will trigger fpga configuration, need to rewrite 1 to make pb[4] available after configuration
  	.system_max_id_0_page_sel_export             (S_page_sel_gui      ), //default=0000,bit3 determine if page_sel_gui[1:0] is active or not. =1, if pb[4] not used, then page_Sel=page_sel_gui[1:0]
  	.system_max_id_0_page_sel_pb_export          (S_pgm_sel_pb_trig   ), //when 1, then page_sel_gui[3]= 0  //press pb4 will clear page_sel_gui[3] automatically
  	.system_max_id_0_pwm_duty_ctrl_export        (pwm_duty_ctrl       ),
  	.system_max_id_0_project_id_export           (proj_id             ),
  	.system_max_id_0_version_export              ({PCB_VERSION, MAX10_VERSION}     ),
	.system_max_id_0_slv_data_read_0_slv_data_read_0 (           ),
  	.system_max_id_0_slv_data_read_1_slv_data_read_1 ( status_gui),
	.system_max_id_0_slv_data_read_2_slv_data_read_2 ({16'd0, dac_i2c_access_state} ),
	.system_max_id_0_slv_data_read_3_slv_data_read_3 ({16'd0, dac_i2c_read_data}   ),
	.system_max_id_0_slv_data_write_0_slv_data_write_0 (system_info_slv_data_write_0),
	.system_max_id_0_slv_data_write_1_slv_data_write_1 (system_info_slv_data_write_1),
	.bmc_i2c_conduit_end_conduit_data_in         (bmc_s_sda_in          ),      
	.bmc_i2c_conduit_end_conduit_clk_in          (bmc_s_scl_in          ),       
	.bmc_i2c_conduit_end_conduit_data_oe         (bmc_s_smbus_sda_oe    ),      
	.bmc_i2c_conduit_end_conduit_clk_oe          (bmc_s_smbus_scl_oe    ),   
	
	.dac_i2c_access_reg_0_conduit_end_state_data   (dac_i2c_access_state ),                      
	.dac_i2c_access_reg_0_conduit_end_clr_inc_dec  (S_clr_inc_dec       ),   
	.dac_i2c_access_reg_0_conduit_end_inc_dec_num  (S_inc_dec_num       ),                      
	.dac_i2c_access_reg_0_conduit_end_inc_decn     (S_inc_decn          ),                      
	.dac_i2c_access_reg_0_conduit_end_start_enable (dac_i2c_access_start ),   //=1 by default
	.dac_i2c_access_reg_0_conduit_end_readdata     (dac_i2c_read_data   ) 	
  	);

  
//-----------------------------------------------------------------------------------------------------------------
  // DAC for VCXO, count pulses
  //-----------------------------------------------------------------------------------------------------------------
  
  assign S_fm_vcxo_dec = sdm_io16 ? fm_vcxo_dec : 1'b0 ; 
  assign S_fm_vcxo_inc = sdm_io16 ? fm_vcxo_inc : 1'b0 ; 
 
  cnt_pulse cnt_pulse_inst(
    .i_clk         (clk_50m_sysmax    ),  
    .i_rstn        (system_max_resetn ),  
    .i_fm_vcxo_dec (S_fm_vcxo_dec     ), 
	 .i_fm_vcxo_inc (S_fm_vcxo_inc     ), 
	 .i_clr_inc_dec (S_clr_inc_dec     ), 
	 .o_inc_decn    (S_inc_decn        ),
    .o_inc_dec_num (S_inc_dec_num     )  
    );
   
endmodule
