-- INTEL CONFIDENTIAL
-- Copyright 2019 Intel Corporation.  All Rights Reserved.
--
-- The source code contained or described herein and all documents related
-- to the source code ("Material") are owned by Intel Corporation or its
-- suppliers or licensors. Title to the Material remains with Intel
-- Corporation or its suppliers and licensors. The Material contains trade
-- secrets and proprietary and confidential information of Intel or its
-- suppliers and licensors. The Material is protected by worldwide copyright
-- and trade secret laws and treaty provisions. No part of the Material may
-- be used, copied, reproduced, modified, published, uploaded, posted,
-- transmitted, distributed, or disclosed in any way without Intel's prior
-- express written permission.
--
-- No license under any patent, copyright, trade secret or other intellectual
-- property right is granted to or conferred upon you by disclosure or
-- delivery of the Materials, either expressly, by implication, inducement,
-- estoppel or otherwise. Any license under such intellectual property rights
-- must be express and approved by Intel in writing.

library ieee;
use ieee.std_logic_1164.all;

entity sys_max_id is
	port (
		reset_n: in std_logic;
		clk : in std_logic;
		version : in std_logic_vector(31 downto 0);
		project_id : in std_logic_vector(15 downto 0);	
	   cpu_resetn : out std_logic;	
		fpga_reconfign : out std_logic;
		fpga_pgm : in std_logic_vector(2 downto 0);
		page_sel : out std_logic_vector(3 downto 0);
		page_sel_pb : in std_logic;	
		control_gui : out std_logic_vector(31 downto 0);
		pwm_duty_ctrl : out std_logic_vector(2 downto 0);
		slv_data_read_0 : in std_logic_vector(31 downto 0);
		slv_data_read_1 : in std_logic_vector(31 downto 0);
		slv_data_read_2 : in std_logic_vector(31 downto 0);
		slv_data_read_3 : in std_logic_vector(31 downto 0);
		slv_data_write_0 : out std_logic_vector(31 downto 0);
		slv_data_write_1 : out std_logic_vector(31 downto 0);
		
		-- interface for AvMM-slave
		slv_en_n : in std_logic;
		slv_address : in std_logic_vector(3 downto 0);
		slv_read_n : in std_logic;
		slv_write_n : in std_logic;
		slv_data_in : in  std_logic_vector(31 downto 0);
		slv_data_out : out std_logic_vector(31 downto 0);
		slv_waitrequest_n : out std_logic -- 0: under process   1:process done, same ad wait_n
	);
end sys_max_id;

architecture rtl of sys_max_id is
	signal trigger, trigger_d1, trigger_d2, trigger_pls : std_logic;
	signal cpu_resetn_int : std_logic;
	signal fpga_reconfign_int : std_logic;
	signal page_sel_int : std_logic_vector (3 downto 0);
	signal control_gui_int : std_logic_vector (31 downto 0);

	signal pwm_duty_ctrl_int : std_logic_vector (2 downto 0);
	signal slv_data_write_0_int : std_logic_vector (31 downto 0);
	signal slv_data_write_1_int : std_logic_vector (31 downto 0);

begin

    cpu_resetn     <=  cpu_resetn_int; 
    fpga_reconfign <=  fpga_reconfign_int;
    page_sel       <=  page_sel_int;
    control_gui    <=  control_gui_int;

	pwm_duty_ctrl   <=  pwm_duty_ctrl_int;
	slv_data_write_0 <= slv_data_write_0_int;
	slv_data_write_1 <= slv_data_write_1_int;

	process(clk, reset_n)begin
		if(reset_n = '0')then
			slv_data_out <= x"00000000";
		elsif(clk'event and clk = '1')then
			if(slv_en_n = '0' and slv_read_n = '0')then
				if(slv_address = "0000")then
					slv_data_out <= version;
				elsif(slv_address = "0001")then
					slv_data_out <= x"0000" & project_id;
				elsif(slv_address = "0010")then
					slv_data_out <= x"0000000" & "000" & cpu_resetn_int;
				elsif(slv_address = "0011")then
					slv_data_out <= X"00000000";
				elsif(slv_address = "0100")then
					slv_data_out <= x"0000000" & page_sel_int(3) & fpga_pgm;
				elsif(slv_address = "0101")then
					slv_data_out <= control_gui_int;
				elsif(slv_address = "0110")then
			      slv_data_out <= x"0000000" & '0' & pwm_duty_ctrl_int;
				elsif(slv_address = "0111")then
					slv_data_out <= slv_data_read_0;
				elsif(slv_address = "1000")then
					slv_data_out <= slv_data_read_1;
				elsif(slv_address = "1001")then
					slv_data_out <= slv_data_read_2;
				elsif(slv_address = "1010")then
					slv_data_out <= slv_data_read_3;
				elsif(slv_address = "1011")then
					slv_data_out <= slv_data_write_0_int;
				elsif(slv_address = "1100")then
					slv_data_out <= slv_data_write_1_int;
				else
					slv_data_out <= x"00000000";
				end if;
			end if;
		end if;
	end process;
	
	process(clk, reset_n)begin
		if(reset_n = '0')then
            cpu_resetn_int <= '1';
            fpga_reconfign_int <= '1';
            page_sel_int <= "0000";
			control_gui_int <= x"0000aa47";
           -- temp_data_int <= x"08";
			pwm_duty_ctrl_int <= "100";
			slv_data_write_0_int <= x"00000000";
			slv_data_write_1_int <= x"00000000";
		elsif(clk'event and clk = '1')then
			if(slv_en_n = '0' and slv_write_n = '0')then
				if(slv_address = "0010")then
					cpu_resetn_int <= slv_data_in(0);
				elsif(slv_address = "0011")then
					fpga_reconfign_int <= slv_data_in(0);
				elsif(slv_address = "0100")then
					page_sel_int <= slv_data_in(3 downto 0);
				elsif(slv_address = "0101")then
					control_gui_int <= slv_data_in;
				elsif(slv_address = "0110")then
			   	pwm_duty_ctrl_int <= slv_data_in(2 downto 0);
				elsif(slv_address = "1011")then
					slv_data_write_0_int <= slv_data_in;
				elsif(slv_address = "1100")then
					slv_data_write_1_int <= slv_data_in;
				end if;
		    elsif (page_sel_pb = '1') then
				page_sel_int(3) <= '0';		
			end if;
		end if;
	end process;
	
	process(clk, reset_n)begin
		if(reset_n = '0')then
			trigger <= '0';
		elsif(clk'event and clk = '1')then
			if(slv_en_n = '0' and (slv_read_n = '0' or slv_write_n = '0'))then
				trigger <= '1';
			else
				trigger <= '0';
			end if;
		end if;
	end process;
	
	process(clk, reset_n)begin
		if(reset_n = '0')then
			trigger_d1 <= '0';
			trigger_d2 <= '1';
		elsif(clk'event and clk = '1')then
			trigger_d2 <= trigger_d1; -- trigger_d1 <= trigger_d2;
			trigger_d1 <= not trigger;
		end if;
	end process;
	
	trigger_pls <= trigger and trigger_d2;
	
	
	process(clk, reset_n)begin
		if(reset_n = '0')then
			slv_waitrequest_n <= '1';
		elsif(clk'event and clk = '1')then
			if(trigger_pls = '1')then
				slv_waitrequest_n <= '1';
			elsif(slv_en_n = '1' or slv_read_n = '1')then
				slv_waitrequest_n <= '0';
			end if;
		end if;
	end process;
	
	
end rtl;
