/*******************************************************************************
* Copyright (C) 2001-2025 Altera Corporation
*
* This code and the related documents are Altera copyrighted materials and
* your use of them is governed by the express license under which they were
* provided to you ("License"). Unless the License provides otherwise, you may
* not use, modify, copy, publish, distribute, disclose, or transmit this
* code or the related documents without Altera's prior written permission.
* 
* This code and the related documents are provided as is, with no express
* or implied warranties other than those that are expressly stated in the
* License.
* 
*******************************************************************************/


//Filename: pulse_generate.v
//Anthor: Anna Gu
//Description: generate pulses according to the value of a register
//revision: 1.0
//revision history: 21-3-1
                                 
											
`timescale 1ns/1ps
module pulse_generate (
    input             clk         ,
	 input             rst_n       ,
	 input  [10:0]     inc_num     ,
	 input  [10:0]     dec_num     ,
    output            inc_pulse,
    output	          dec_pulse,
	 output            clr_inc_num,
	 output            clr_dec_num,
	 output reg [15:0]   state_data
);
reg  S_inc_pulse;
reg  S_dec_pulse;
reg  S_clr_inc_num;
reg  S_clr_dec_num;
reg [10:0] S_inc_cnt;
reg [10:0] S_dec_cnt;
reg [10:0] S_inc_num;
reg [10:0] S_dec_num;
reg [10:0] S_inc_num_d1;
reg [10:0] S_dec_num_d1;
reg [10:0] S_inc_num_d2;
reg [10:0] S_dec_num_d2;
reg [1:0]   state;
reg  inc_high_low_sw;
reg  dec_high_low_sw;
localparam IDLE           = 2'd0;
localparam DRIVE_PULSE  = 2'd1;
localparam DONE = 2'd2;
assign inc_pulse =S_inc_pulse;
assign dec_pulse =S_dec_pulse;
assign clr_inc_num =S_clr_inc_num;
assign clr_dec_num =S_clr_dec_num;
always @(posedge clk or negedge rst_n) begin
  if (~rst_n) begin
    S_inc_num_d1   <= 11'd0;
	 S_dec_num_d1   <= 11'd0;
	 S_inc_num_d2   <= 11'd0;
	 S_dec_num_d2   <= 11'd0;
  end
  else begin
    S_inc_num_d1   <= inc_num;
	 S_inc_num_d2   <= S_inc_num_d1;
	 S_dec_num_d1   <= dec_num;
	 S_dec_num_d2   <= S_dec_num_d1;
  end
end
always @(posedge clk or negedge rst_n) begin
  if (~rst_n) begin
    S_inc_pulse <= 1'b0;
	 S_dec_pulse <= 1'b0;
	 S_inc_cnt   <= 11'd0;
	 S_dec_cnt   <= 11'd0;
	 S_inc_num   <= 11'd0;
	 S_dec_num   <= 11'd0;
	 S_clr_inc_num   <= 1'b0;
	 S_clr_dec_num   <= 1'b0;
	 inc_high_low_sw  <= 1'b0;
	 dec_high_low_sw  <= 1'b0;
  end
  else begin
    case (state)
      IDLE: begin
	     S_inc_pulse <= 1'b0;
	     S_dec_pulse <= 1'b0;
	     S_inc_cnt   <= 11'd0;
	     S_dec_cnt   <= 11'd0;
		  inc_high_low_sw  <= 1'b0;
		  dec_high_low_sw  <= 1'b0;
		  if ((S_inc_num_d2 != 11'd0) || (S_dec_num_d2 != 11'd0)) begin
		    state <= DRIVE_PULSE;
			 if (S_inc_num_d2 != 11'd0) begin
	         S_inc_num <= S_inc_num_d2;
	         S_clr_inc_num   <= 1'b1;
	       end
			 else begin
			   S_inc_num <= 11'd0;
	         S_clr_inc_num   <= 1'b0;
			 end
	       if (S_dec_num_d2 != 11'd0) begin
	         S_dec_num <= S_dec_num_d2;
	         S_clr_dec_num   <= 1'b1;
	       end 
			 else begin
			   S_dec_num <= 11'd0;
	         S_clr_dec_num   <= 1'b0;
			 end
		  end		  
		end
		 
		DRIVE_PULSE: begin
		  if (S_clr_inc_num) begin
			 if (S_inc_cnt == S_inc_num) begin
				S_clr_inc_num   <= 1'b0;
		    end
			 else if ( inc_high_low_sw) begin
				S_inc_pulse <= 1'b0;
				inc_high_low_sw <= 1'b0;
				S_inc_cnt   <= S_inc_cnt + 1'b1;
			 end
			 else if ( !inc_high_low_sw) begin
				S_inc_pulse <= 1'b1;
				inc_high_low_sw <= 1'b1;
			 end
		  end
		  if (S_clr_dec_num) begin
		    if (S_dec_cnt == S_dec_num) begin
				S_clr_dec_num   <= 1'b0;
		    end
			 else if ( dec_high_low_sw) begin
				S_dec_pulse <= 1'b0;
				dec_high_low_sw <= 1'b0;
				S_dec_cnt   <= S_dec_cnt + 1'b1;
			 end
			 else if ( !dec_high_low_sw) begin
				S_dec_pulse <= 1'b1;
				dec_high_low_sw <= 1'b1;
			 end
		  end
		  if ((!S_clr_inc_num) && (!S_clr_dec_num)) begin
		    state <= DONE;
		  end
		end
		
		DONE: begin
		  state <= IDLE;
		end
      default: begin
		  state <= IDLE;
		end
    endcase		
  end	      
end
 always @(posedge clk)
  state_data <= {12'd0,S_clr_inc_num, S_clr_dec_num, state}; 
endmodule
