/*******************************************************************************
* Copyright (C) 2001-2025 Altera Corporation
*
* This code and the related documents are Altera copyrighted materials and
* your use of them is governed by the express license under which they were
* provided to you ("License"). Unless the License provides otherwise, you may
* not use, modify, copy, publish, distribute, disclose, or transmit this
* code or the related documents without Altera's prior written permission.
* 
* This code and the related documents are provided as is, with no express
* or implied warranties other than those that are expressly stated in the
* License.
* 
*******************************************************************************/


/*
This module is to convert XCVR native PHY signals to Qsys capable signals.
Converts conduit to Avalon-Streaming signals.



*/

module  xcvr_st_converter #( 
	parameter DATAWIDTH = 320)
	( 
	//local side
	input  [DATAWIDTH*4/5-1 : 0]tx_data_a,
	output [DATAWIDTH*4/5-1 : 0]rx_data_a,
	output tx_clkout_a,
	output rx_clkout_a,
	output tx_clkout_sample,
	output tx_clkout_a_output,
	output rx_clkout_a_output,
	

	//XCVR side
	input  tx_clkout,
	output [DATAWIDTH-1 : 0]tx_parallel_data, 
	input  rx_clkout,
	input [DATAWIDTH-1 : 0]rx_parallel_data	
);

	assign tx_parallel_data[DATAWIDTH-1:0] = {8'h80,tx_data_a[255:224],8'h40, tx_data_a[223:192], 8'h80,tx_data_a[191:160],8'h40, tx_data_a[159:128], 8'h80,tx_data_a[127:96],8'h40, tx_data_a[95:64], 8'h80,tx_data_a[63:32],8'h40, tx_data_a[31:0]}; //[311:280],[271:240],[231:200],[191:160],[151:120],[111:80],[71:40],[31:0],256-bit active
	assign rx_data_a = {rx_parallel_data[311:280],rx_parallel_data[271:240], rx_parallel_data[231:200],rx_parallel_data[191:160],rx_parallel_data[151:120],rx_parallel_data[111:80], rx_parallel_data[71:40],rx_parallel_data[31:0]}; //[311:280],[271:240],[231:200],[191:160],[151:120],[111:80], [71:40],[31:0],256-bit active

	assign tx_clkout_a = tx_clkout;
	assign rx_clkout_a = rx_clkout;
	assign tx_clkout_sample = tx_clkout;

	assign tx_clkout_a_output = tx_clkout;
	assign rx_clkout_a_output = rx_clkout;


endmodule


